from collections.abc import Callable, Iterable
from datetime import date, datetime, timedelta
from time import _TimeTuple, struct_time
from typing import Any, Generic, NamedTuple, TypeVar, overload
from typing_extensions import TypeAlias

from webob.byterange import ContentRange, Range
from webob.etag import IfRange, IfRangeDate

_T = TypeVar("_T")
_DefaultT = TypeVar("_DefaultT")
_GetterReturnType = TypeVar("_GetterReturnType")
_SetterValueType = TypeVar("_SetterValueType")
_ConvertedGetterReturnType = TypeVar("_ConvertedGetterReturnType")
_ConvertedSetterValueType = TypeVar("_ConvertedSetterValueType")
_ContentRangeParams: TypeAlias = (
    ContentRange
    | list[int]
    | list[None]
    | list[int | None]
    | tuple[int, int]
    | tuple[None, None]
    | tuple[int, int, int | None]
    | tuple[None, None, int | None]
    | str
    | None
)

class _AsymmetricProperty(Generic[_GetterReturnType, _SetterValueType]):
    @overload
    def __get__(self, obj: None, type: type | None = ..., /) -> property: ...
    @overload
    def __get__(self, obj: Any, type: type | None = ..., /) -> _GetterReturnType: ...
    def __set__(self, obj: Any, value: _SetterValueType, /) -> None: ...

class _AsymmetricPropertyWithDelete(_AsymmetricProperty[_GetterReturnType, _SetterValueType]):
    def __delete__(self, obj: Any, /) -> None: ...

class _SymmetricProperty(_AsymmetricProperty[_T, _T]): ...
class _SymmetricPropertyWithDelete(_AsymmetricPropertyWithDelete[_T, _T]): ...
class _StringProperty(_SymmetricPropertyWithDelete[str | None]): ...
class _ListProperty(_AsymmetricPropertyWithDelete[tuple[str, ...] | None, Iterable[str] | str | None]): ...
class _DateProperty(
    _AsymmetricPropertyWithDelete[datetime | None, date | datetime | timedelta | _TimeTuple | struct_time | float | str | None]
): ...

@overload
def environ_getter(key: str, default: None, rfc_section: str | None = None) -> _SymmetricPropertyWithDelete[Any | None]: ...
@overload
def environ_getter(
    key: str, default: _DefaultT, rfc_section: str | None = None
) -> _AsymmetricPropertyWithDelete[Any | _DefaultT, Any | _DefaultT | None]: ...
@overload
def environ_getter(key: str, *, rfc_section: str | None = None) -> _SymmetricProperty[Any]: ...
@overload
def environ_decoder(
    key: str, default: str, rfc_section: str | None = None, encattr: str | None = None
) -> _AsymmetricPropertyWithDelete[str, str | None]: ...
@overload
def environ_decoder(
    key: str, default: None, rfc_section: str | None = None, encattr: str | None = None
) -> _SymmetricPropertyWithDelete[str | None]: ...
@overload
def environ_decoder(key: str, *, rfc_section: str | None = None, encattr: str | None = None) -> _SymmetricProperty[str]: ...
def upath_property(key: str) -> _SymmetricProperty[str]: ...
def deprecated_property(attr: _T, name: str, text: str, version: str) -> _T: ...
def header_getter(header: str, rfc_section: str) -> _StringProperty: ...
@overload
def converter(
    prop: _AsymmetricPropertyWithDelete[_GetterReturnType, _SetterValueType],
    parse: Callable[[_GetterReturnType], _ConvertedGetterReturnType],
    serialize: Callable[[_ConvertedSetterValueType], _SetterValueType],
    convert_name: str | None = None,
) -> _AsymmetricPropertyWithDelete[_ConvertedGetterReturnType, _ConvertedSetterValueType]: ...
@overload
def converter(
    prop: _AsymmetricProperty[_GetterReturnType, _SetterValueType],
    parse: Callable[[_GetterReturnType], _ConvertedGetterReturnType],
    serialize: Callable[[_ConvertedSetterValueType], _SetterValueType],
    convert_name: str | None = None,
) -> _AsymmetricProperty[_ConvertedGetterReturnType, _ConvertedSetterValueType]: ...
def list_header(header: str, rfc_section: str) -> _ListProperty: ...
def parse_list(value: str | None) -> tuple[str, ...] | None: ...
def serialize_list(value: Iterable[str] | str) -> str: ...
def converter_date(prop: _StringProperty) -> _DateProperty: ...
def date_header(header: str, rfc_section: str) -> _DateProperty: ...
def parse_etag_response(value: str | None, strong: bool = False) -> str | None: ...
def serialize_etag_response(value: str | tuple[str, bool]) -> str: ...
def serialize_if_range(value: IfRange | IfRangeDate | datetime | date | str) -> str | None: ...
def parse_range(value: str | None) -> Range | None: ...
def serialize_range(value: tuple[int, int | None] | list[int | None] | list[int] | str | None) -> str | None: ...
def parse_int(value: str | None) -> int | None: ...
def parse_int_safe(value: str | None) -> int | None: ...

serialize_int: Callable[[int], str]

def parse_content_range(value: str | None) -> ContentRange | None: ...
def serialize_content_range(value: _ContentRangeParams) -> str | None: ...
def parse_auth_params(params: str) -> dict[str, str]: ...

known_auth_schemes: dict[str, None]

class _authorization(NamedTuple):
    authtype: str
    params: dict[str, str] | str

def parse_auth(val: str | None) -> _authorization | None: ...
def serialize_auth(val: tuple[str, dict[str, str] | str] | list[Any] | str | None) -> str | None: ...



from _typeshed import ReadableBuffer

class Error(Exception): ...

def ZSTD_compress(data: ReadableBuffer, level: int = ..., threads: int = ..., /) -> bytes: ...
def ZSTD_external() -> int: ...
def ZSTD_uncompress(data: ReadableBuffer, /) -> bytes: ...
def ZSTD_version() -> str: ...
def ZSTD_version_number() -> int: ...
def ZSTD_threads_count() -> int: ...
def ZSTD_max_threads_count() -> int: ...
def compress(data: ReadableBuffer, level: int = ..., threads: int = ..., /) -> bytes: ...
def decompress(data: ReadableBuffer, /) -> bytes: ...
def dumps(data: ReadableBuffer, level: int = ..., threads: int = ..., /) -> bytes: ...
def loads(data: ReadableBuffer, /) -> bytes: ...
def uncompress(data: ReadableBuffer, /) -> bytes: ...
def version() -> str: ...



from _typeshed import Incomplete

from networkx.utils.backends import _dispatch

class CurrentEdge:
    def __init__(self, edges) -> None: ...
    def get(self): ...
    def move_to_next(self) -> None: ...

class Level:
    active: Incomplete
    inactive: Incomplete
    def __init__(self) -> None: ...

class GlobalRelabelThreshold:
    def __init__(self, n, m, freq) -> None: ...
    def add_work(self, work) -> None: ...
    def is_reached(self): ...
    def clear_work(self) -> None: ...

@_dispatch
def build_residual_network(G, capacity): ...
@_dispatch
def detect_unboundedness(R, s, t) -> None: ...
@_dispatch
def build_flow_dict(G, R): ...



from collections.abc import Generator

from consolemenu.console_menu import MenuItem
from consolemenu.format import MenuBorderStyle, MenuMargins, MenuPadding, MenuStyle as MenuStyle

def ansilen(s: str) -> int: ...

class Dimension:
    width: int
    height: int
    def __init__(self, width: int = 0, height: int = 0, dimension: Dimension | None = None) -> None: ...

class MenuComponent:
    def __init__(self, menu_style: MenuStyle, max_dimension: Dimension | None = None) -> None: ...
    @property
    def max_dimension(self) -> Dimension: ...
    @property
    def style(self) -> MenuStyle: ...
    @property
    def margins(self) -> MenuMargins: ...
    @property
    def padding(self) -> MenuPadding: ...
    @property
    def border_style(self) -> MenuBorderStyle: ...
    def calculate_border_width(self) -> int: ...
    def calculate_content_width(self) -> int: ...
    def generate(self) -> Generator[str, None, None]: ...
    def inner_horizontals(self) -> str: ...
    def inner_horizontal_border(self) -> str: ...
    def outer_horizontals(self) -> str: ...
    def outer_horizontal_border_bottom(self) -> str: ...
    def outer_horizontal_border_top(self) -> str: ...
    def row(self, content: str = "", align: str = "left", indent_len: int = 0) -> str: ...

class MenuHeader(MenuComponent):
    title: str
    title_align: str
    subtitle: str
    subtitle_align: str
    show_bottom_border: bool
    def __init__(
        self,
        menu_style: MenuStyle,
        max_dimension: Dimension | None = None,
        title: str | None = None,
        title_align: str = "left",
        subtitle: str | None = None,
        subtitle_align: str = "left",
        show_bottom_border: bool = False,
    ) -> None: ...
    def generate(self) -> Generator[str, None, None]: ...

class MenuTextSection(MenuComponent):
    text: str
    text_align: str
    show_top_border: bool
    show_bottom_border: bool
    def __init__(
        self,
        menu_style: MenuStyle,
        max_dimension: Dimension | None = None,
        text: str | None = None,
        text_align: str = "left",
        show_top_border: bool = False,
        show_bottom_border: bool = False,
    ) -> None: ...
    def generate(self) -> Generator[str, None, None]: ...

class MenuItemsSection(MenuComponent):
    items_align: str
    def __init__(
        self,
        menu_style: MenuStyle,
        max_dimension: Dimension | None = None,
        items: list[MenuItem] | None = None,
        items_align: str = "left",
    ) -> None: ...
    @property
    def items(self) -> list[MenuItem]: ...
    @items.setter
    def items(self, items: list[MenuItem]) -> None: ...
    @property
    def items_with_bottom_border(self) -> list[str]: ...
    @property
    def items_with_top_border(self) -> list[str]: ...
    def show_item_bottom_border(self, item_text: str, flag: bool) -> None: ...
    def show_item_top_border(self, item_text: str, flag: bool) -> None: ...
    def generate(self) -> Generator[str, None, None]: ...

class MenuFooter(MenuComponent):
    def generate(self) -> Generator[str, None, None]: ...

class MenuPrompt(MenuComponent):
    def __init__(self, menu_style: MenuStyle, max_dimension: Dimension | None = None, prompt_string: str = ">>") -> None: ...
    @property
    def prompt(self) -> str: ...
    @prompt.setter
    def prompt(self, prompt: str) -> None: ...
    def generate(self) -> Generator[str, None, None]: ...



from _typeshed import Incomplete

class SepaDirectDebitAccountGateway:
    gateway: Incomplete
    config: Incomplete
    def __init__(self, gateway) -> None: ...
    def find(self, sepa_direct_debit_account_token): ...
    def delete(self, sepa_direct_debit_account_token): ...



ABOVE_NORMAL_PRIORITY_CLASS: int
BELOW_NORMAL_PRIORITY_CLASS: int
ERROR_ACCESS_DENIED: int
ERROR_INVALID_NAME: int
ERROR_PRIVILEGE_NOT_HELD: int
ERROR_SERVICE_DOES_NOT_EXIST: int
HIGH_PRIORITY_CLASS: int
IDLE_PRIORITY_CLASS: int
INFINITE: int
MIB_TCP_STATE_CLOSED: int
MIB_TCP_STATE_CLOSE_WAIT: int
MIB_TCP_STATE_CLOSING: int
MIB_TCP_STATE_DELETE_TCB: int
MIB_TCP_STATE_ESTAB: int
MIB_TCP_STATE_FIN_WAIT1: int
MIB_TCP_STATE_FIN_WAIT2: int
MIB_TCP_STATE_LAST_ACK: int
MIB_TCP_STATE_LISTEN: int
MIB_TCP_STATE_SYN_RCVD: int
MIB_TCP_STATE_SYN_SENT: int
MIB_TCP_STATE_TIME_WAIT: int
NORMAL_PRIORITY_CLASS: int
PSUTIL_CONN_NONE: int
REALTIME_PRIORITY_CLASS: int
WINDOWS_10: int
WINDOWS_7: int
WINDOWS_8: int
WINDOWS_8_1: int
WINDOWS_VISTA: int
WINVER: int
version: int

class TimeoutAbandoned(Exception): ...
class TimeoutExpired(Exception): ...

def QueryDosDevice(*args, **kwargs): ...  # incomplete
def boot_time(*args, **kwargs): ...  # incomplete
def check_pid_range(pid: int, /) -> None: ...
def cpu_count_cores(*args, **kwargs): ...  # incomplete
def cpu_count_logical(*args, **kwargs): ...  # incomplete
def cpu_freq(*args, **kwargs): ...  # incomplete
def cpu_stats(*args, **kwargs): ...  # incomplete
def cpu_times(*args, **kwargs): ...  # incomplete
def disk_io_counters(*args, **kwargs): ...  # incomplete
def disk_partitions(*args, **kwargs): ...  # incomplete
def disk_usage(*args, **kwargs): ...  # incomplete
def getloadavg(*args, **kwargs): ...  # incomplete
def getpagesize(*args, **kwargs): ...  # incomplete
def init_loadavg_counter(*args, **kwargs): ...  # incomplete
def net_connections(*args, **kwargs): ...  # incomplete
def net_if_addrs(*args, **kwargs): ...  # incomplete
def net_if_stats(*args, **kwargs): ...  # incomplete
def net_io_counters(*args, **kwargs): ...  # incomplete
def per_cpu_times(*args, **kwargs): ...  # incomplete
def pid_exists(*args, **kwargs): ...  # incomplete
def pids(*args, **kwargs): ...  # incomplete
def ppid_map(*args, **kwargs): ...  # incomplete
def proc_cmdline(*args, **kwargs): ...  # incomplete
def proc_cpu_affinity_get(*args, **kwargs): ...  # incomplete
def proc_cpu_affinity_set(*args, **kwargs): ...  # incomplete
def proc_cwd(*args, **kwargs): ...  # incomplete
def proc_environ(*args, **kwargs): ...  # incomplete
def proc_exe(*args, **kwargs): ...  # incomplete
def proc_info(*args, **kwargs): ...  # incomplete
def proc_io_counters(*args, **kwargs): ...  # incomplete
def proc_io_priority_get(*args, **kwargs): ...  # incomplete
def proc_io_priority_set(*args, **kwargs): ...  # incomplete
def proc_is_suspended(*args, **kwargs): ...  # incomplete
def proc_kill(*args, **kwargs): ...  # incomplete
def proc_memory_info(*args, **kwargs): ...  # incomplete
def proc_memory_maps(*args, **kwargs): ...  # incomplete
def proc_memory_uss(*args, **kwargs): ...  # incomplete
def proc_num_handles(*args, **kwargs): ...  # incomplete
def proc_open_files(*args, **kwargs): ...  # incomplete
def proc_priority_get(*args, **kwargs): ...  # incomplete
def proc_priority_set(*args, **kwargs): ...  # incomplete
def proc_suspend_or_resume(*args, **kwargs): ...  # incomplete
def proc_threads(*args, **kwargs): ...  # incomplete
def proc_times(*args, **kwargs): ...  # incomplete
def proc_username(*args, **kwargs): ...  # incomplete
def proc_wait(*args, **kwargs): ...  # incomplete
def sensors_battery(*args, **kwargs): ...  # incomplete
def set_debug(*args, **kwargs): ...  # incomplete
def swap_percent(*args, **kwargs): ...  # incomplete
def users(*args, **kwargs): ...  # incomplete
def virtual_mem(*args, **kwargs): ...  # incomplete
def winservice_enumerate(*args, **kwargs): ...  # incomplete
def winservice_query_config(*args, **kwargs): ...  # incomplete
def winservice_query_descr(*args, **kwargs): ...  # incomplete
def winservice_query_status(*args, **kwargs): ...  # incomplete
def winservice_start(*args, **kwargs): ...  # incomplete
def winservice_stop(*args, **kwargs): ...  # incomplete



from _typeshed import Incomplete

from docutils.nodes import Node, document

class Transform:
    def __init__(self, document: document, startnode: Node | None = None): ...
    def __getattr__(self, name: str, /) -> Incomplete: ...

class Transformer:
    def __init__(self, document: document): ...
    def add_transform(self, transform_class: type[Transform], priority: int | None = None, **kwargs) -> None: ...
    def __getattr__(self, name: str, /) -> Incomplete: ...

def __getattr__(name: str) -> Incomplete: ...



from collections.abc import Generator
from zipfile import ZipFile

from openpyxl.packaging.relationship import Relationship, RelationshipList
from openpyxl.packaging.workbook import ChildSheet, PivotCache
from openpyxl.pivot.cache import CacheDefinition
from openpyxl.workbook import Workbook

class WorkbookParser:
    archive: ZipFile
    workbook_part_name: str
    wb: Workbook
    keep_links: bool
    sheets: list[ChildSheet]
    def __init__(self, archive: ZipFile, workbook_part_name: str, keep_links: bool = True) -> None: ...
    @property
    def rels(self) -> RelationshipList: ...
    # Errors if "parse" is never called.
    caches: list[PivotCache]
    def parse(self) -> None: ...
    def find_sheets(self) -> Generator[tuple[ChildSheet, Relationship], None, None]: ...
    def assign_names(self) -> None: ...
    @property
    def pivot_caches(self) -> dict[int, CacheDefinition]: ...



from collections.abc import Hashable
from typing import TypeVar

from networkx.classes.digraph import DiGraph
from networkx.utils.backends import _dispatch

@_dispatch
def disjoint_union(G, H): ...
@_dispatch
def intersection(G, H): ...
@_dispatch
def difference(G, H): ...
@_dispatch
def symmetric_difference(G, H): ...

_X = TypeVar("_X", bound=Hashable, covariant=True)
_Y = TypeVar("_Y", bound=Hashable, covariant=True)
# GT = TypeVar('GT', bound=Graph[_Node])
# TODO: This does not handle the cases when graphs of different types are passed which is allowed

@_dispatch
def compose(G: DiGraph[_X], H: DiGraph[_Y]) -> DiGraph[_X | _Y]: ...
@_dispatch
def union(G: DiGraph[_X], H: DiGraph[_Y], rename=()) -> DiGraph[_X | _Y]: ...



from _typeshed import Incomplete
from typing import ClassVar, Literal

from .ImageFile import ImageFile

xbm_head: Incomplete

class XbmImageFile(ImageFile):
    format: ClassVar[Literal["XBM"]]
    format_description: ClassVar[str]



from _typeshed import Incomplete
from multiprocessing.pool import ApplyResult
from typing import Literal, overload

from influxdb_client.domain.tasks import Tasks
from influxdb_client.service._base_service import _BaseService

class TasksService(_BaseService):
    def __init__(self, api_client: Incomplete | None = None) -> None: ...
    def delete_tasks_id(self, task_id, **kwargs): ...
    def delete_tasks_id_with_http_info(self, task_id, **kwargs): ...
    async def delete_tasks_id_async(self, task_id, **kwargs): ...
    def delete_tasks_id_labels_id(self, task_id, label_id, **kwargs): ...
    def delete_tasks_id_labels_id_with_http_info(self, task_id, label_id, **kwargs): ...
    async def delete_tasks_id_labels_id_async(self, task_id, label_id, **kwargs): ...
    def delete_tasks_id_members_id(self, user_id, task_id, **kwargs): ...
    def delete_tasks_id_members_id_with_http_info(self, user_id, task_id, **kwargs): ...
    async def delete_tasks_id_members_id_async(self, user_id, task_id, **kwargs): ...
    def delete_tasks_id_owners_id(self, user_id, task_id, **kwargs): ...
    def delete_tasks_id_owners_id_with_http_info(self, user_id, task_id, **kwargs): ...
    async def delete_tasks_id_owners_id_async(self, user_id, task_id, **kwargs): ...
    def delete_tasks_id_runs_id(self, task_id, run_id, **kwargs): ...
    def delete_tasks_id_runs_id_with_http_info(self, task_id, run_id, **kwargs): ...
    async def delete_tasks_id_runs_id_async(self, task_id, run_id, **kwargs): ...
    @overload
    def get_tasks(
        self,
        *,
        async_req: Literal[True],
        urlopen_kw=...,
        zap_trace_span: str = ...,
        name: str = ...,
        after: str = ...,
        user: str = ...,
        org: str = ...,
        org_id: str = ...,
        limit: int = ...,
        type: str = ...,
    ) -> ApplyResult[Tasks]: ...
    @overload
    def get_tasks(
        self,
        *,
        async_req: Literal[False] = ...,
        urlopen_kw=...,
        zap_trace_span: str = ...,
        name: str = ...,
        after: str = ...,
        user: str = ...,
        org: str = ...,
        org_id: str = ...,
        limit: int = ...,
        type: str = ...,
    ) -> Tasks: ...
    @overload
    def get_tasks_with_http_info(
        self,
        *,
        async_req: Literal[True],
        urlopen_kw=...,
        zap_trace_span: str = ...,
        name: str = ...,
        after: str = ...,
        user: str = ...,
        org: str = ...,
        org_id: str = ...,
        limit: int = ...,
        type: str = ...,
    ) -> ApplyResult[Tasks]: ...
    @overload
    def get_tasks_with_http_info(
        self,
        *,
        async_req: Literal[False] = ...,
        urlopen_kw=...,
        zap_trace_span: str = ...,
        name: str = ...,
        after: str = ...,
        user: str = ...,
        org: str = ...,
        org_id: str = ...,
        limit: int = ...,
        type: str = ...,
    ) -> Tasks: ...
    async def get_tasks_async(self, **kwargs): ...
    def get_tasks_id(self, task_id, **kwargs): ...
    def get_tasks_id_with_http_info(self, task_id, **kwargs): ...
    async def get_tasks_id_async(self, task_id, **kwargs): ...
    def get_tasks_id_labels(self, task_id, **kwargs): ...
    def get_tasks_id_labels_with_http_info(self, task_id, **kwargs): ...
    async def get_tasks_id_labels_async(self, task_id, **kwargs): ...
    def get_tasks_id_logs(self, task_id, **kwargs): ...
    def get_tasks_id_logs_with_http_info(self, task_id, **kwargs): ...
    async def get_tasks_id_logs_async(self, task_id, **kwargs): ...
    def get_tasks_id_members(self, task_id, **kwargs): ...
    def get_tasks_id_members_with_http_info(self, task_id, **kwargs): ...
    async def get_tasks_id_members_async(self, task_id, **kwargs): ...
    def get_tasks_id_owners(self, task_id, **kwargs): ...
    def get_tasks_id_owners_with_http_info(self, task_id, **kwargs): ...
    async def get_tasks_id_owners_async(self, task_id, **kwargs): ...
    def get_tasks_id_runs(self, task_id, **kwargs): ...
    def get_tasks_id_runs_with_http_info(self, task_id, **kwargs): ...
    async def get_tasks_id_runs_async(self, task_id, **kwargs): ...
    def get_tasks_id_runs_id(self, task_id, run_id, **kwargs): ...
    def get_tasks_id_runs_id_with_http_info(self, task_id, run_id, **kwargs): ...
    async def get_tasks_id_runs_id_async(self, task_id, run_id, **kwargs): ...
    def get_tasks_id_runs_id_logs(self, task_id, run_id, **kwargs): ...
    def get_tasks_id_runs_id_logs_with_http_info(self, task_id, run_id, **kwargs): ...
    async def get_tasks_id_runs_id_logs_async(self, task_id, run_id, **kwargs): ...
    def patch_tasks_id(self, task_id, task_update_request, **kwargs): ...
    def patch_tasks_id_with_http_info(self, task_id, task_update_request, **kwargs): ...
    async def patch_tasks_id_async(self, task_id, task_update_request, **kwargs): ...
    def post_tasks(self, task_create_request, **kwargs): ...
    def post_tasks_with_http_info(self, task_create_request, **kwargs): ...
    async def post_tasks_async(self, task_create_request, **kwargs): ...
    def post_tasks_id_labels(self, task_id, label_mapping, **kwargs): ...
    def post_tasks_id_labels_with_http_info(self, task_id, label_mapping, **kwargs): ...
    async def post_tasks_id_labels_async(self, task_id, label_mapping, **kwargs): ...
    def post_tasks_id_members(self, task_id, add_resource_member_request_body, **kwargs): ...
    def post_tasks_id_members_with_http_info(self, task_id, add_resource_member_request_body, **kwargs): ...
    async def post_tasks_id_members_async(self, task_id, add_resource_member_request_body, **kwargs): ...
    def post_tasks_id_owners(self, task_id, add_resource_member_request_body, **kwargs): ...
    def post_tasks_id_owners_with_http_info(self, task_id, add_resource_member_request_body, **kwargs): ...
    async def post_tasks_id_owners_async(self, task_id, add_resource_member_request_body, **kwargs): ...
    def post_tasks_id_runs(self, task_id, **kwargs): ...
    def post_tasks_id_runs_with_http_info(self, task_id, **kwargs): ...
    async def post_tasks_id_runs_async(self, task_id, **kwargs): ...
    def post_tasks_id_runs_id_retry(self, task_id, run_id, **kwargs): ...
    def post_tasks_id_runs_id_retry_with_http_info(self, task_id, run_id, **kwargs): ...
    async def post_tasks_id_runs_id_retry_async(self, task_id, run_id, **kwargs): ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
Protocol Buffers - Google's data interchange format
Copyright 2008 Google Inc.  All rights reserved.
https://developers.google.com/protocol-buffers/

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are
met:

    * Redistributions of source code must retain the above copyright
notice, this list of conditions and the following disclaimer.
    * Redistributions in binary form must reproduce the above
copyright notice, this list of conditions and the following disclaimer
in the documentation and/or other materials provided with the
distribution.
    * Neither the name of Google Inc. nor the names of its
contributors may be used to endorse or promote products derived from
this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
"""

import typing as typing_extensions

import google.protobuf.descriptor
import google.protobuf.message

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Empty(google.protobuf.message.Message):
    """A generic empty message that you can re-use to avoid defining duplicated
    empty messages in your APIs. A typical example is to use it as the request
    or the response type of an API method. For instance:

        service Foo {
          rpc Bar(google.protobuf.Empty) returns (google.protobuf.Empty);
        }
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___Empty = Empty



from braintree.resource import Resource

class MetaCheckoutToken(Resource):
    def __init__(self, gateway, attributes) -> None: ...
    @property
    def expiration_date(self): ...
    @property
    def masked_number(self): ...



from _typeshed import Incomplete
from collections.abc import Iterator
from typing import ClassVar, Final, Literal
from typing_extensions import TypeAlias

from openpyxl.descriptors.base import Alias, Bool, NoneSet, Typed, _ConvertibleToBool
from openpyxl.descriptors.serialisable import Serialisable
from openpyxl.styles.colors import Color, ColorDescriptor

_SideStyle: TypeAlias = Literal[
    "dashDot",
    "dashDotDot",
    "dashed",
    "dotted",
    "double",
    "hair",
    "medium",
    "mediumDashDot",
    "mediumDashDotDot",
    "mediumDashed",
    "slantDashDot",
    "thick",
    "thin",
]

BORDER_NONE: Final = None
BORDER_DASHDOT: Final = "dashDot"
BORDER_DASHDOTDOT: Final = "dashDotDot"
BORDER_DASHED: Final = "dashed"
BORDER_DOTTED: Final = "dotted"
BORDER_DOUBLE: Final = "double"
BORDER_HAIR: Final = "hair"
BORDER_MEDIUM: Final = "medium"
BORDER_MEDIUMDASHDOT: Final = "mediumDashDot"
BORDER_MEDIUMDASHDOTDOT: Final = "mediumDashDotDot"
BORDER_MEDIUMDASHED: Final = "mediumDashed"
BORDER_SLANTDASHDOT: Final = "slantDashDot"
BORDER_THICK: Final = "thick"
BORDER_THIN: Final = "thin"

class Side(Serialisable):
    __fields__: ClassVar[tuple[str, ...]]
    color: ColorDescriptor[Literal[True]]
    style: NoneSet[_SideStyle]
    border_style: Alias
    def __init__(
        self,
        style: _SideStyle | Literal["none"] | None = None,
        color: str | Color | None = None,
        border_style: Incomplete | None = None,
    ) -> None: ...

class Border(Serialisable):
    tagname: ClassVar[str]
    __fields__: ClassVar[tuple[str, ...]]
    __elements__: ClassVar[tuple[str, ...]]
    start: Typed[Side, Literal[True]]
    end: Typed[Side, Literal[True]]
    left: Typed[Side, Literal[True]]
    right: Typed[Side, Literal[True]]
    top: Typed[Side, Literal[True]]
    bottom: Typed[Side, Literal[True]]
    diagonal: Typed[Side, Literal[True]]
    vertical: Typed[Side, Literal[True]]
    horizontal: Typed[Side, Literal[True]]
    outline: Bool[Literal[False]]
    diagonalUp: Bool[Literal[False]]
    diagonalDown: Bool[Literal[False]]
    diagonal_direction: Incomplete
    def __init__(
        self,
        left: Side | None = None,
        right: Side | None = None,
        top: Side | None = None,
        bottom: Side | None = None,
        diagonal: Side | None = None,
        diagonal_direction: Incomplete | None = None,
        vertical: Side | None = None,
        horizontal: Side | None = None,
        diagonalUp: _ConvertibleToBool = False,
        diagonalDown: _ConvertibleToBool = False,
        outline: _ConvertibleToBool = True,
        start: Side | None = None,
        end: Side | None = None,
    ) -> None: ...
    def __iter__(self) -> Iterator[tuple[str, str]]: ...

DEFAULT_BORDER: Final[Border]



from _typeshed import Incomplete

from networkx.utils.backends import _dispatch

@_dispatch
def lukes_partitioning(G, max_size, node_weight: Incomplete | None = None, edge_weight: Incomplete | None = None): ...



from _typeshed import Incomplete
from typing import Any

class Tag:
    key: Any
    value: Any
    def __init__(self, key: Incomplete | None = None, value: Incomplete | None = None) -> None: ...
    def startElement(self, name, attrs, connection): ...
    def endElement(self, name, value, connection): ...
    def to_xml(self): ...
    def __eq__(self, other): ...

class TagSet(list[Tag]):
    def startElement(self, name, attrs, connection): ...
    def endElement(self, name, value, connection): ...
    def add_tag(self, key, value): ...
    def to_xml(self): ...

class Tags(list[TagSet]):
    def startElement(self, name, attrs, connection): ...
    def endElement(self, name, value, connection): ...
    def to_xml(self): ...
    def add_tag_set(self, tag_set): ...



from _typeshed import Incomplete
from collections.abc import Iterator

from networkx.classes.coreviews import AdjacencyView
from networkx.classes.graph import Graph, _Node
from networkx.classes.reportviews import (
    InDegreeView,
    InEdgeView,
    InMultiDegreeView,
    OutDegreeView,
    OutEdgeView,
    OutMultiDegreeView,
)

class DiGraph(Graph[_Node]):
    succ: AdjacencyView[_Node, _Node, dict[str, Incomplete]]
    pred: AdjacencyView[_Node, _Node, dict[str, Incomplete]]
    def has_successor(self, u: _Node, v: _Node) -> bool: ...
    def has_predecessor(self, u: _Node, v: _Node) -> bool: ...
    def successors(self, n: _Node) -> Iterator[_Node]: ...
    def predecessors(self, n: _Node) -> Iterator[_Node]: ...
    in_edges: InEdgeView[_Node]
    in_degree: InDegreeView[_Node] | InMultiDegreeView[_Node]  # ugly hack to make MultiDiGraph work
    out_edges: OutEdgeView[_Node]
    out_degree: OutDegreeView[_Node] | OutMultiDegreeView[_Node]  # ugly hack to make MultiDiGraph work
    def to_undirected(self, reciprocal: bool = False, as_view: bool = False): ...  # type: ignore[override]  # Has an additional `reciprocal` keyword argument
    def reverse(self, copy: bool = True) -> DiGraph[_Node]: ...
    def copy(self, as_view: bool = False) -> DiGraph[_Node]: ...



from _typeshed import ReadableBuffer, SupportsRead, SupportsWrite
from collections import OrderedDict
from collections.abc import Mapping
from types import GeneratorType
from typing import Any, overload

__license__: str

class ParsingInterrupted(Exception): ...

def parse(
    xml_input: str | ReadableBuffer | SupportsRead[bytes] | GeneratorType[ReadableBuffer, Any, Any],
    encoding: str | None = ...,
    expat: Any = ...,
    process_namespaces: bool = ...,
    namespace_separator: str = ...,
    disable_entities: bool = ...,
    process_comments: bool = ...,
    **kwargs: Any,
) -> OrderedDict[str, Any]: ...
@overload
def unparse(
    input_dict: Mapping[str, Any],
    output: SupportsWrite[bytes] | SupportsWrite[str],
    encoding: str = ...,
    full_document: bool = ...,
    short_empty_elements: bool = ...,
    **kwargs: Any,
) -> None: ...
@overload
def unparse(
    input_dict: Mapping[str, Any],
    output: None = ...,
    encoding: str = ...,
    full_document: bool = ...,
    short_empty_elements: bool = ...,
    **kwargs: Any,
) -> str: ...



from _typeshed import Incomplete
from typing import ClassVar

from .core import UnitedStates

class Missouri(UnitedStates):
    FIXED_HOLIDAYS: Incomplete
    include_lincoln_birthday: ClassVar[bool]



from collections.abc import Callable
from typing import Any, ClassVar
from typing_extensions import Self

from .upload import upload

class upload_docs(upload):
    DEFAULT_REPOSITORY: ClassVar[str]
    description: ClassVar[str]
    user_options: ClassVar[list[tuple[str, str | None, str]]]
    boolean_options: ClassVar[list[str]]
    def has_sphinx(self): ...
    # The callable parameter is self: Self, but using Self still trips up mypy
    sub_commands: ClassVar[list[tuple[str, Callable[[Self], bool] | None]]]  # type: ignore[assignment]
    upload_dir: Any
    target_dir: Any
    def initialize_options(self) -> None: ...
    def finalize_options(self) -> None: ...
    def create_zipfile(self, filename) -> None: ...
    def run(self) -> None: ...
    def upload_file(self, filename) -> None: ...  # type: ignore[override]



from _typeshed import Incomplete
from collections.abc import Iterable

from qrcode.image.base import BaseImage, DrawerAliases as DrawerAliases

default_factories: Incomplete
error_correction: Incomplete

def main(args: Incomplete | None = None) -> None: ...
def get_factory(module: str) -> type[BaseImage]: ...
def get_drawer_help() -> str: ...
def commas(items: Iterable[str], joiner: str = "or") -> str: ...



import sys
import types
from _typeshed import Incomplete, ReadableBuffer, WriteableBuffer
from collections.abc import Callable, Hashable
from typing import Any, ClassVar, Literal, Protocol, SupportsIndex, TypeVar, final, overload
from typing_extensions import TypeAlias

_T = TypeVar("_T")

class _Allocator(Protocol):
    def __call__(self, cdecl: str | CType, init: Any = ...) -> _CDataBase: ...

__version__: str

FFI_CDECL: int
FFI_DEFAULT_ABI: int
RTLD_GLOBAL: int
RTLD_LAZY: int
RTLD_LOCAL: int
RTLD_NOW: int
if sys.platform == "linux":
    RTLD_DEEPBIND: int
if sys.platform != "win32":
    RTLD_NODELETE: int
    RTLD_NOLOAD: int

@final
class CField:
    bitshift: Incomplete
    bitsize: Incomplete
    flags: Incomplete
    offset: Incomplete
    type: Incomplete

@final
class CLibrary:
    def close_lib(self, *args, **kwargs): ...
    def load_function(self, *args, **kwargs): ...
    def read_variable(self, *args, **kwargs): ...
    def write_variable(self, *args, **kwargs): ...

@final
class CType:
    abi: Incomplete
    args: Incomplete
    cname: Incomplete
    elements: Incomplete
    ellipsis: Incomplete
    fields: Incomplete
    item: Incomplete
    kind: Incomplete
    length: Incomplete
    relements: Incomplete
    result: Incomplete
    def __dir__(self): ...

@final
class Lib:
    def __dir__(self): ...

@final
class _CDataBase:
    __name__: ClassVar[str]
    def __add__(self, other): ...
    def __bool__(self) -> bool: ...
    def __call__(self, *args, **kwargs): ...
    def __complex__(self) -> complex: ...
    def __delitem__(self, other) -> None: ...
    def __dir__(self): ...
    def __enter__(self): ...
    def __eq__(self, other): ...
    def __exit__(self, type: type[BaseException] | None, value: BaseException | None, traceback: types.TracebackType | None): ...
    def __float__(self) -> float: ...
    def __ge__(self, other): ...
    def __getitem__(self, index: SupportsIndex | slice): ...
    def __gt__(self, other): ...
    def __hash__(self) -> int: ...
    def __int__(self) -> int: ...
    def __iter__(self): ...
    def __le__(self, other): ...
    def __len__(self) -> int: ...
    def __lt__(self, other): ...
    def __ne__(self, other): ...
    def __radd__(self, other): ...
    def __rsub__(self, other): ...
    def __setitem__(self, index: SupportsIndex | slice, object) -> None: ...
    def __sub__(self, other): ...

@final
class buffer:
    __hash__: ClassVar[None]  # type: ignore[assignment]
    def __init__(self, *args, **kwargs) -> None: ...
    def __delitem__(self, other) -> None: ...
    def __eq__(self, other): ...
    def __ge__(self, other): ...
    def __getitem__(self, index): ...
    def __gt__(self, other): ...
    def __le__(self, other): ...
    def __len__(self) -> int: ...
    def __lt__(self, other): ...
    def __ne__(self, other): ...
    def __setitem__(self, index, object) -> None: ...

# These aliases are to work around pyright complaints.
# Pyright doesn't like it when a class object is defined as an alias
# of a global object with the same name.
_tmp_CType = CType
_tmp_buffer = buffer

class FFI:
    CData: TypeAlias = _CDataBase
    CType: TypeAlias = _tmp_CType
    buffer: TypeAlias = _tmp_buffer  # noqa: Y042

    class error(Exception): ...
    NULL: ClassVar[CData]
    RTLD_GLOBAL: ClassVar[int]
    RTLD_LAZY: ClassVar[int]
    RTLD_LOCAL: ClassVar[int]
    RTLD_NOW: ClassVar[int]
    if sys.platform != "win32":
        RTLD_DEEPBIND: ClassVar[int]
        RTLD_NODELETE: ClassVar[int]
        RTLD_NOLOAD: ClassVar[int]

    errno: int

    def __init__(
        self,
        module_name: str = ...,
        _version: int = ...,
        _types: str = ...,
        _globals: tuple[str | int, ...] = ...,
        _struct_unions: tuple[tuple[str, ...], ...] = ...,
        _enums: tuple[str, ...] = ...,
        _typenames: tuple[str, ...] = ...,
        _includes: tuple[FFI, ...] = ...,
    ) -> None: ...
    @overload
    def addressof(self, cdata: CData, /, *field_or_index: str | int) -> CData: ...
    @overload
    def addressof(self, library: Lib, name: str, /) -> CData: ...
    def alignof(self, cdecl: str | CType | CData, /) -> int: ...
    @overload
    def callback(
        self,
        cdecl: str | CType,
        python_callable: None = ...,
        error: Any = ...,
        onerror: Callable[[Exception, Any, Any], None] | None = ...,
    ) -> Callable[[Callable[..., _T]], Callable[..., _T]]: ...
    @overload
    def callback(
        self,
        cdecl: str | CType,
        python_callable: Callable[..., _T],
        error: Any = ...,
        onerror: Callable[[Exception, Any, Any], None] | None = ...,
    ) -> Callable[..., _T]: ...
    def cast(self, cdecl: str | CType, value: CData) -> CData: ...
    def def_extern(
        self, name: str = ..., error: Any = ..., onerror: Callable[[Exception, Any, types.TracebackType], Any] = ...
    ) -> Callable[[Callable[..., _T]], Callable[..., _T]]: ...
    def dlclose(self, lib: Lib, /) -> None: ...
    if sys.platform == "win32":
        def dlopen(self, libpath: str | CData, flags: int = ..., /) -> Lib: ...
    else:
        def dlopen(self, libpath: str | CData | None = ..., flags: int = ..., /) -> Lib: ...

    @overload
    def from_buffer(self, cdecl: ReadableBuffer, require_writable: Literal[False] = ...) -> CData: ...
    @overload
    def from_buffer(self, cdecl: WriteableBuffer, require_writable: Literal[True]) -> CData: ...
    @overload
    def from_buffer(self, cdecl: str | CType, python_buffer: ReadableBuffer, require_writable: Literal[False] = ...) -> CData: ...
    @overload
    def from_buffer(self, cdecl: str | CType, python_buffer: WriteableBuffer, require_writable: Literal[True]) -> CData: ...
    def from_handle(self, x: CData, /) -> Any: ...
    @overload
    def gc(self, cdata: CData, destructor: Callable[[CData], Any], size: int = ...) -> CData: ...
    @overload
    def gc(self, cdata: CData, destructor: None, size: int = ...) -> None: ...
    def getctype(self, cdecl: str | CType, replace_with: str = ...) -> str: ...
    if sys.platform == "win32":
        def getwinerror(self, code: int = ...) -> tuple[int, str]: ...

    def init_once(self, func: Callable[[], Any], tag: Hashable) -> Any: ...
    def integer_const(self, name: str) -> int: ...
    def list_types(self) -> tuple[list[str], list[str], list[str]]: ...
    def memmove(self, dest: CData | WriteableBuffer, src: CData | ReadableBuffer, n: int) -> None: ...
    def new(self, cdecl: str | CType, init: Any = ...) -> CData: ...
    @overload
    def new_allocator(self, alloc: None = ..., free: None = ..., should_clear_after_alloc: bool = ...) -> _Allocator: ...
    @overload
    def new_allocator(
        self, alloc: Callable[[int], CData], free: None = ..., should_clear_after_alloc: bool = ...
    ) -> _Allocator: ...
    @overload
    def new_allocator(
        self, alloc: Callable[[int], CData], free: Callable[[CData], Any], should_clear_after_alloc: bool = ...
    ) -> _Allocator: ...
    def new_handle(self, x: Any, /) -> CData: ...
    def offsetof(self, cdecl: str | CType, field_or_index: str | int, /, *__fields_or_indexes: str | int) -> int: ...
    def release(self, cdata: CData, /) -> None: ...
    def sizeof(self, cdecl: str | CType | CData, /) -> int: ...
    def string(self, cdata: CData, maxlen: int = -1) -> bytes | str: ...
    def typeof(self, cdecl: str | CData) -> CType: ...
    def unpack(self, cdata: CData, length: int) -> bytes | str | list[Any]: ...

def alignof(cdecl: CType, /) -> int: ...
def callback(
    cdecl: CType,
    python_callable: Callable[..., _T],
    error: Any = ...,
    onerror: Callable[[Exception, Any, Any], None] | None = ...,
    /,
) -> Callable[..., _T]: ...
def cast(cdecl: CType, value: _CDataBase, /) -> _CDataBase: ...
def complete_struct_or_union(
    cdecl: CType,
    fields: list[tuple[str, CType, int, int]],
    ignored: Any,
    total_size: int,
    total_alignment: int,
    sflags: int,
    pack: int,
    /,
) -> None: ...
@overload
def from_buffer(cdecl: CType, python_buffer: ReadableBuffer, /, require_writable: Literal[False] = ...) -> _CDataBase: ...
@overload
def from_buffer(cdecl: CType, python_buffer: WriteableBuffer, /, require_writable: Literal[True]) -> _CDataBase: ...
def from_handle(x: _CDataBase, /) -> Any: ...
@overload
def gcp(cdata: _CDataBase, destructor: Callable[[_CDataBase], Any], size: int = ...) -> _CDataBase: ...
@overload
def gcp(cdata: _CDataBase, destructor: None, size: int = ...) -> None: ...
def get_errno() -> int: ...
def getcname(cdecl: CType, replace_with: str, /) -> str: ...

if sys.platform == "win32":
    def getwinerror(code: int = ...) -> tuple[int, str]: ...

if sys.platform == "win32":
    def load_library(libpath: str | _CDataBase, flags: int = ..., /) -> CLibrary: ...

else:
    def load_library(libpath: str | _CDataBase | None = ..., flags: int = ..., /) -> CLibrary: ...

def memmove(dest: _CDataBase | WriteableBuffer, src: _CDataBase | ReadableBuffer, n: int) -> None: ...
def new_array_type(cdecl: CType, length: int | None, /) -> CType: ...
def new_enum_type(name: str, enumerators: tuple[str, ...], enumvalues: tuple[Any, ...], basetype: CType, /) -> CType: ...
def new_function_type(args: tuple[CType, ...], result: CType, ellipsis: int, abi: int, /) -> CType: ...
def new_pointer_type(cdecl: CType, /) -> CType: ...
def new_primitive_type(name: str, /) -> CType: ...
def new_struct_type(name: str, /) -> CType: ...
def new_union_type(name: str, /) -> CType: ...
def new_void_type() -> CType: ...
def newp(cdecl: CType, init: Any = ..., /) -> _CDataBase: ...
def newp_handle(cdecl: CType, x: Any, /) -> _CDataBase: ...
def rawaddressof(cdecl: CType, cdata: _CDataBase, offset: int, /) -> _CDataBase: ...
def release(cdata: _CDataBase, /) -> None: ...
def set_errno(errno: int, /) -> None: ...
def sizeof(cdecl: CType | _CDataBase, /) -> int: ...
def string(cdata: _CDataBase, maxlen: int) -> bytes | str: ...
def typeof(cdata: _CDataBase, /) -> CType: ...
def typeoffsetof(cdecl: CType, fieldname: str | int, following: bool = ..., /) -> tuple[CType, int]: ...
def unpack(cdata: _CDataBase, length: int) -> bytes | str | list[Any]: ...



# pyjks exports lots of junk such as jks.jks.SIGNATURE_WHITENING, jks.util.b8 etc.
# We don't mark those as re-exported as those don't seem like intended part of the public API.
from .bks import (
    AbstractBksEntry as AbstractBksEntry,
    BksKeyEntry as BksKeyEntry,
    BksKeyStore as BksKeyStore,
    BksSealedKeyEntry as BksSealedKeyEntry,
    BksSecretKeyEntry as BksSecretKeyEntry,
    BksTrustedCertEntry as BksTrustedCertEntry,
    UberKeyStore as UberKeyStore,
)
from .jks import (
    KeyStore as KeyStore,
    PrivateKeyEntry as PrivateKeyEntry,
    SecretKeyEntry as SecretKeyEntry,
    TrustedCertEntry as TrustedCertEntry,
    __version__ as __version__,
    __version_info__ as __version_info__,
)
from .util import (
    AbstractKeystore as AbstractKeystore,
    AbstractKeystoreEntry as AbstractKeystoreEntry,
    BadDataLengthException as BadDataLengthException,
    BadHashCheckException as BadHashCheckException,
    BadKeystoreFormatException as BadKeystoreFormatException,
    BadPaddingException as BadPaddingException,
    DecryptionFailureException as DecryptionFailureException,
    DuplicateAliasException as DuplicateAliasException,
    KeystoreException as KeystoreException,
    KeystoreSignatureException as KeystoreSignatureException,
    NotYetDecryptedException as NotYetDecryptedException,
    UnexpectedAlgorithmException as UnexpectedAlgorithmException,
    UnexpectedJavaTypeException as UnexpectedJavaTypeException,
    UnexpectedKeyEncodingException as UnexpectedKeyEncodingException,
    UnsupportedKeyFormatException as UnsupportedKeyFormatException,
    UnsupportedKeystoreEntryTypeException as UnsupportedKeystoreEntryTypeException,
    UnsupportedKeystoreTypeException as UnsupportedKeystoreTypeException,
    UnsupportedKeystoreVersionException as UnsupportedKeystoreVersionException,
    add_pkcs7_padding as add_pkcs7_padding,
    as_hex as as_hex,
    as_pem as as_pem,
    bitstring_to_bytes as bitstring_to_bytes,
    pkey_as_pem as pkey_as_pem,
    print_pem as print_pem,
    strip_pkcs5_padding as strip_pkcs5_padding,
    strip_pkcs7_padding as strip_pkcs7_padding,
    xor_bytearrays as xor_bytearrays,
)



from _typeshed import Incomplete

from hvac.api.system_backend.system_backend_mixin import SystemBackendMixin

class Init(SystemBackendMixin):
    def read_init_status(self): ...
    def is_initialized(self): ...
    def initialize(
        self,
        secret_shares: Incomplete | None = None,
        secret_threshold: Incomplete | None = None,
        pgp_keys: Incomplete | None = None,
        root_token_pgp_key: Incomplete | None = None,
        stored_shares: Incomplete | None = None,
        recovery_shares: Incomplete | None = None,
        recovery_threshold: Incomplete | None = None,
        recovery_pgp_keys: Incomplete | None = None,
    ): ...



from _typeshed import Incomplete

def random_layout(G, center: Incomplete | None = None, dim: int = 2, seed: Incomplete | None = None): ...
def circular_layout(G, scale: float = 1, center: Incomplete | None = None, dim: int = 2): ...
def shell_layout(
    G,
    nlist: Incomplete | None = None,
    rotate: Incomplete | None = None,
    scale: float = 1,
    center: Incomplete | None = None,
    dim: int = 2,
): ...
def bipartite_layout(
    G, nodes, align: str = "vertical", scale: float = 1, center: Incomplete | None = None, aspect_ratio: float = ...
): ...
def spring_layout(
    G,
    k: Incomplete | None = None,
    pos: Incomplete | None = None,
    fixed: Incomplete | None = None,
    iterations: int = 50,
    threshold: float = 0.0001,
    weight: str = "weight",
    scale: float = 1,
    center: Incomplete | None = None,
    dim: int = 2,
    seed: Incomplete | None = None,
): ...

fruchterman_reingold_layout = spring_layout

def kamada_kawai_layout(
    G,
    dist: Incomplete | None = None,
    pos: Incomplete | None = None,
    weight: str = "weight",
    scale: float = 1,
    center: Incomplete | None = None,
    dim: int = 2,
): ...
def spectral_layout(G, weight: str = "weight", scale: float = 1, center: Incomplete | None = None, dim: int = 2): ...
def planar_layout(G, scale: float = 1, center: Incomplete | None = None, dim: int = 2): ...
def spiral_layout(
    G, scale: float = 1, center: Incomplete | None = None, dim: int = 2, resolution: float = 0.35, equidistant: bool = False
): ...
def multipartite_layout(
    G, subset_key: str = "subset", align: str = "vertical", scale: float = 1, center: Incomplete | None = None
): ...
def arf_layout(
    G,
    pos: Incomplete | None = None,
    scaling: float = 1,
    a: float = 1.1,
    etol: float = 1e-06,
    dt: float = 0.001,
    max_iter: int = 1000,
): ...
def rescale_layout(pos, scale: float = 1): ...
def rescale_layout_dict(pos, scale: float = 1): ...



from _typeshed import Incomplete
from typing import Final

from braintree.merchant_account import BusinessDetails, FundingDetails, IndividualDetails
from braintree.resource import Resource

class MerchantAccount(Resource):
    class Status:
        Active: Final = "active"
        Pending: Final = "pending"
        Suspended: Final = "suspended"

    class FundingDestination:
        Bank: Final = "bank"
        Email: Final = "email"
        MobilePhone: Final = "mobile_phone"

    FundingDestinations: type[FundingDestination]
    individual_details: IndividualDetails
    business_details: BusinessDetails
    funding_details: FundingDetails
    master_merchant_account: MerchantAccount
    def __init__(self, gateway, attributes) -> None: ...
    @staticmethod
    def create(params: Incomplete | None = None): ...
    @staticmethod
    def update(id, attributes): ...
    @staticmethod
    def find(id): ...



from _typeshed import Incomplete
from collections.abc import Generator

from networkx.utils.backends import _dispatch

@_dispatch
def is_eulerian(G): ...
@_dispatch
def is_semieulerian(G): ...
@_dispatch
def eulerian_circuit(G, source: Incomplete | None = None, keys: bool = False) -> Generator[Incomplete, Incomplete, None]: ...
@_dispatch
def has_eulerian_path(G, source: Incomplete | None = None): ...
@_dispatch
def eulerian_path(G, source: Incomplete | None = None, keys: bool = False) -> Generator[Incomplete, Incomplete, None]: ...
@_dispatch
def eulerize(G): ...



from webob.datetime_utils import (
    UTC as UTC,
    day as day,
    hour as hour,
    minute as minute,
    month as month,
    second as second,
    week as week,
    year as year,
)
from webob.request import LegacyRequest as LegacyRequest, Request as Request
from webob.response import Response as Response
from webob.util import html_escape as html_escape



from _typeshed import Incomplete
from collections.abc import Generator

from networkx.utils.backends import _dispatch

def generate_multiline_adjlist(G, delimiter: str = " ") -> Generator[Incomplete, None, None]: ...
def write_multiline_adjlist(G, path, delimiter: str = " ", comments: str = "#", encoding: str = "utf-8") -> None: ...
@_dispatch
def parse_multiline_adjlist(
    lines,
    comments: str = "#",
    delimiter: Incomplete | None = None,
    create_using: Incomplete | None = None,
    nodetype: Incomplete | None = None,
    edgetype: Incomplete | None = None,
): ...
@_dispatch
def read_multiline_adjlist(
    path,
    comments: str = "#",
    delimiter: Incomplete | None = None,
    create_using: Incomplete | None = None,
    nodetype: Incomplete | None = None,
    edgetype: Incomplete | None = None,
    encoding: str = "utf-8",
): ...



from _typeshed import Incomplete
from typing import Any

from bs4.builder import HTMLTreeBuilder
from html5lib.treebuilders import base as treebuilder_base

class HTML5TreeBuilder(HTMLTreeBuilder):
    NAME: str
    features: Any
    TRACKS_LINE_NUMBERS: bool
    user_specified_encoding: Any
    def prepare_markup(  # type: ignore[override]  # user_specified_encoding doesn't have a default
        self,
        markup,
        user_specified_encoding,
        document_declared_encoding: Incomplete | None = ...,
        exclude_encodings: Incomplete | None = ...,
    ) -> None: ...
    def feed(self, markup) -> None: ...
    underlying_builder: Any
    def create_treebuilder(self, namespaceHTMLElements): ...
    def test_fragment_to_document(self, fragment): ...

class TreeBuilderForHtml5lib(treebuilder_base.TreeBuilder):
    soup: Any
    parser: Any
    store_line_numbers: Any
    def __init__(
        self, namespaceHTMLElements, soup: Incomplete | None = ..., store_line_numbers: bool = ..., **kwargs
    ) -> None: ...
    def documentClass(self): ...
    def insertDoctype(self, token) -> None: ...
    def elementClass(self, name, namespace): ...
    def commentClass(self, data): ...
    def fragmentClass(self): ...
    def appendChild(self, node) -> None: ...
    def getDocument(self): ...
    def getFragment(self): ...
    def testSerializer(self, element): ...

class AttrList:
    element: Any
    attrs: Any
    def __init__(self, element) -> None: ...
    def __iter__(self): ...
    def __setitem__(self, name, value) -> None: ...
    def items(self): ...
    def keys(self): ...
    def __len__(self) -> int: ...
    def __getitem__(self, name): ...
    def __contains__(self, name): ...

class Element(treebuilder_base.Node):
    element: Any
    soup: Any
    namespace: Any
    def __init__(self, element, soup, namespace) -> None: ...
    def appendChild(self, node) -> None: ...
    def getAttributes(self): ...
    def setAttributes(self, attributes) -> None: ...
    attributes: Any
    def insertText(self, data, insertBefore: Incomplete | None = ...) -> None: ...
    def insertBefore(self, node, refNode) -> None: ...
    def removeChild(self, node) -> None: ...
    def reparentChildren(self, new_parent) -> None: ...
    def cloneNode(self): ...
    def hasContent(self): ...
    def getNameTuple(self): ...
    @property
    def nameTuple(self): ...

class TextNode(Element):
    element: Any
    soup: Any
    def __init__(self, element, soup) -> None: ...
    def cloneNode(self) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import sys
import typing

import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import s2clientprotocol.common_pb2

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _DebugGameState:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _DebugGameStateEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_DebugGameState.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    show_map: _DebugGameState.ValueType  # 1
    control_enemy: _DebugGameState.ValueType  # 2
    food: _DebugGameState.ValueType  # 3
    free: _DebugGameState.ValueType  # 4
    all_resources: _DebugGameState.ValueType  # 5
    god: _DebugGameState.ValueType  # 6
    minerals: _DebugGameState.ValueType  # 7
    gas: _DebugGameState.ValueType  # 8
    cooldown: _DebugGameState.ValueType  # 9
    tech_tree: _DebugGameState.ValueType  # 10
    upgrade: _DebugGameState.ValueType  # 11
    fast_build: _DebugGameState.ValueType  # 12

class DebugGameState(_DebugGameState, metaclass=_DebugGameStateEnumTypeWrapper): ...

show_map: DebugGameState.ValueType  # 1
control_enemy: DebugGameState.ValueType  # 2
food: DebugGameState.ValueType  # 3
free: DebugGameState.ValueType  # 4
all_resources: DebugGameState.ValueType  # 5
god: DebugGameState.ValueType  # 6
minerals: DebugGameState.ValueType  # 7
gas: DebugGameState.ValueType  # 8
cooldown: DebugGameState.ValueType  # 9
tech_tree: DebugGameState.ValueType  # 10
upgrade: DebugGameState.ValueType  # 11
fast_build: DebugGameState.ValueType  # 12
global___DebugGameState = DebugGameState

@typing_extensions.final
class DebugCommand(google.protobuf.message.Message):
    """Issue various useful commands to the game engine."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DRAW_FIELD_NUMBER: builtins.int
    GAME_STATE_FIELD_NUMBER: builtins.int
    CREATE_UNIT_FIELD_NUMBER: builtins.int
    KILL_UNIT_FIELD_NUMBER: builtins.int
    TEST_PROCESS_FIELD_NUMBER: builtins.int
    SCORE_FIELD_NUMBER: builtins.int
    END_GAME_FIELD_NUMBER: builtins.int
    UNIT_VALUE_FIELD_NUMBER: builtins.int
    @property
    def draw(self) -> global___DebugDraw: ...
    game_state: global___DebugGameState.ValueType
    @property
    def create_unit(self) -> global___DebugCreateUnit: ...
    @property
    def kill_unit(self) -> global___DebugKillUnit: ...
    @property
    def test_process(self) -> global___DebugTestProcess: ...
    @property
    def score(self) -> global___DebugSetScore:
        """Useful only for single-player "curriculum" maps."""
    @property
    def end_game(self) -> global___DebugEndGame: ...
    @property
    def unit_value(self) -> global___DebugSetUnitValue: ...
    def __init__(
        self,
        *,
        draw: global___DebugDraw | None = ...,
        game_state: global___DebugGameState.ValueType | None = ...,
        create_unit: global___DebugCreateUnit | None = ...,
        kill_unit: global___DebugKillUnit | None = ...,
        test_process: global___DebugTestProcess | None = ...,
        score: global___DebugSetScore | None = ...,
        end_game: global___DebugEndGame | None = ...,
        unit_value: global___DebugSetUnitValue | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["command", b"command", "create_unit", b"create_unit", "draw", b"draw", "end_game", b"end_game", "game_state", b"game_state", "kill_unit", b"kill_unit", "score", b"score", "test_process", b"test_process", "unit_value", b"unit_value"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["command", b"command", "create_unit", b"create_unit", "draw", b"draw", "end_game", b"end_game", "game_state", b"game_state", "kill_unit", b"kill_unit", "score", b"score", "test_process", b"test_process", "unit_value", b"unit_value"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["command", b"command"]) -> typing_extensions.Literal["draw", "game_state", "create_unit", "kill_unit", "test_process", "score", "end_game", "unit_value"] | None: ...

global___DebugCommand = DebugCommand

@typing_extensions.final
class DebugDraw(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TEXT_FIELD_NUMBER: builtins.int
    LINES_FIELD_NUMBER: builtins.int
    BOXES_FIELD_NUMBER: builtins.int
    SPHERES_FIELD_NUMBER: builtins.int
    @property
    def text(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DebugText]: ...
    @property
    def lines(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DebugLine]: ...
    @property
    def boxes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DebugBox]: ...
    @property
    def spheres(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DebugSphere]: ...
    def __init__(
        self,
        *,
        text: collections.abc.Iterable[global___DebugText] | None = ...,
        lines: collections.abc.Iterable[global___DebugLine] | None = ...,
        boxes: collections.abc.Iterable[global___DebugBox] | None = ...,
        spheres: collections.abc.Iterable[global___DebugSphere] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["boxes", b"boxes", "lines", b"lines", "spheres", b"spheres", "text", b"text"]) -> None: ...

global___DebugDraw = DebugDraw

@typing_extensions.final
class Line(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    P0_FIELD_NUMBER: builtins.int
    P1_FIELD_NUMBER: builtins.int
    @property
    def p0(self) -> s2clientprotocol.common_pb2.Point: ...
    @property
    def p1(self) -> s2clientprotocol.common_pb2.Point: ...
    def __init__(
        self,
        *,
        p0: s2clientprotocol.common_pb2.Point | None = ...,
        p1: s2clientprotocol.common_pb2.Point | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["p0", b"p0", "p1", b"p1"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["p0", b"p0", "p1", b"p1"]) -> None: ...

global___Line = Line

@typing_extensions.final
class Color(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    R_FIELD_NUMBER: builtins.int
    G_FIELD_NUMBER: builtins.int
    B_FIELD_NUMBER: builtins.int
    r: builtins.int
    g: builtins.int
    b: builtins.int
    def __init__(
        self,
        *,
        r: builtins.int | None = ...,
        g: builtins.int | None = ...,
        b: builtins.int | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["b", b"b", "g", b"g", "r", b"r"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["b", b"b", "g", b"g", "r", b"r"]) -> None: ...

global___Color = Color

@typing_extensions.final
class DebugText(google.protobuf.message.Message):
    """Display debug text on screen."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COLOR_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    VIRTUAL_POS_FIELD_NUMBER: builtins.int
    WORLD_POS_FIELD_NUMBER: builtins.int
    SIZE_FIELD_NUMBER: builtins.int
    @property
    def color(self) -> global___Color: ...
    text: builtins.str
    """Text to display."""
    @property
    def virtual_pos(self) -> s2clientprotocol.common_pb2.Point:
        """Virtualized position in 2D (the screen is 0..1, 0..1 for any resolution)."""
    @property
    def world_pos(self) -> s2clientprotocol.common_pb2.Point:
        """Position in the world."""
    size: builtins.int
    """Pixel height of the text. Defaults to 8px."""
    def __init__(
        self,
        *,
        color: global___Color | None = ...,
        text: builtins.str | None = ...,
        virtual_pos: s2clientprotocol.common_pb2.Point | None = ...,
        world_pos: s2clientprotocol.common_pb2.Point | None = ...,
        size: builtins.int | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["color", b"color", "size", b"size", "text", b"text", "virtual_pos", b"virtual_pos", "world_pos", b"world_pos"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["color", b"color", "size", b"size", "text", b"text", "virtual_pos", b"virtual_pos", "world_pos", b"world_pos"]) -> None: ...

global___DebugText = DebugText

@typing_extensions.final
class DebugLine(google.protobuf.message.Message):
    """Display debug lines on screen."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COLOR_FIELD_NUMBER: builtins.int
    LINE_FIELD_NUMBER: builtins.int
    @property
    def color(self) -> global___Color: ...
    @property
    def line(self) -> global___Line:
        """World space line."""
    def __init__(
        self,
        *,
        color: global___Color | None = ...,
        line: global___Line | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["color", b"color", "line", b"line"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["color", b"color", "line", b"line"]) -> None: ...

global___DebugLine = DebugLine

@typing_extensions.final
class DebugBox(google.protobuf.message.Message):
    """Display debug boxes on screen."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COLOR_FIELD_NUMBER: builtins.int
    MIN_FIELD_NUMBER: builtins.int
    MAX_FIELD_NUMBER: builtins.int
    @property
    def color(self) -> global___Color: ...
    @property
    def min(self) -> s2clientprotocol.common_pb2.Point: ...
    @property
    def max(self) -> s2clientprotocol.common_pb2.Point: ...
    def __init__(
        self,
        *,
        color: global___Color | None = ...,
        min: s2clientprotocol.common_pb2.Point | None = ...,
        max: s2clientprotocol.common_pb2.Point | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["color", b"color", "max", b"max", "min", b"min"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["color", b"color", "max", b"max", "min", b"min"]) -> None: ...

global___DebugBox = DebugBox

@typing_extensions.final
class DebugSphere(google.protobuf.message.Message):
    """Display debug spheres on screen."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COLOR_FIELD_NUMBER: builtins.int
    P_FIELD_NUMBER: builtins.int
    R_FIELD_NUMBER: builtins.int
    @property
    def color(self) -> global___Color: ...
    @property
    def p(self) -> s2clientprotocol.common_pb2.Point: ...
    r: builtins.float
    def __init__(
        self,
        *,
        color: global___Color | None = ...,
        p: s2clientprotocol.common_pb2.Point | None = ...,
        r: builtins.float | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["color", b"color", "p", b"p", "r", b"r"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["color", b"color", "p", b"p", "r", b"r"]) -> None: ...

global___DebugSphere = DebugSphere

@typing_extensions.final
class DebugCreateUnit(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    UNIT_TYPE_FIELD_NUMBER: builtins.int
    OWNER_FIELD_NUMBER: builtins.int
    POS_FIELD_NUMBER: builtins.int
    QUANTITY_FIELD_NUMBER: builtins.int
    unit_type: builtins.int
    owner: builtins.int
    @property
    def pos(self) -> s2clientprotocol.common_pb2.Point2D: ...
    quantity: builtins.int
    def __init__(
        self,
        *,
        unit_type: builtins.int | None = ...,
        owner: builtins.int | None = ...,
        pos: s2clientprotocol.common_pb2.Point2D | None = ...,
        quantity: builtins.int | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["owner", b"owner", "pos", b"pos", "quantity", b"quantity", "unit_type", b"unit_type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["owner", b"owner", "pos", b"pos", "quantity", b"quantity", "unit_type", b"unit_type"]) -> None: ...

global___DebugCreateUnit = DebugCreateUnit

@typing_extensions.final
class DebugKillUnit(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TAG_FIELD_NUMBER: builtins.int
    @property
    def tag(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]: ...
    def __init__(
        self,
        *,
        tag: collections.abc.Iterable[builtins.int] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["tag", b"tag"]) -> None: ...

global___DebugKillUnit = DebugKillUnit

@typing_extensions.final
class DebugTestProcess(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Test:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _TestEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[DebugTestProcess._Test.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        hang: DebugTestProcess._Test.ValueType  # 1
        crash: DebugTestProcess._Test.ValueType  # 2
        exit: DebugTestProcess._Test.ValueType  # 3

    class Test(_Test, metaclass=_TestEnumTypeWrapper): ...
    hang: DebugTestProcess.Test.ValueType  # 1
    crash: DebugTestProcess.Test.ValueType  # 2
    exit: DebugTestProcess.Test.ValueType  # 3

    TEST_FIELD_NUMBER: builtins.int
    DELAY_MS_FIELD_NUMBER: builtins.int
    test: global___DebugTestProcess.Test.ValueType
    delay_ms: builtins.int
    def __init__(
        self,
        *,
        test: global___DebugTestProcess.Test.ValueType | None = ...,
        delay_ms: builtins.int | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["delay_ms", b"delay_ms", "test", b"test"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["delay_ms", b"delay_ms", "test", b"test"]) -> None: ...

global___DebugTestProcess = DebugTestProcess

@typing_extensions.final
class DebugSetScore(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SCORE_FIELD_NUMBER: builtins.int
    score: builtins.float
    def __init__(
        self,
        *,
        score: builtins.float | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["score", b"score"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["score", b"score"]) -> None: ...

global___DebugSetScore = DebugSetScore

@typing_extensions.final
class DebugEndGame(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _EndResult:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _EndResultEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[DebugEndGame._EndResult.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        Surrender: DebugEndGame._EndResult.ValueType  # 1
        """Default if nothing is set. The current player admits defeat."""
        DeclareVictory: DebugEndGame._EndResult.ValueType  # 2

    class EndResult(_EndResult, metaclass=_EndResultEnumTypeWrapper): ...
    Surrender: DebugEndGame.EndResult.ValueType  # 1
    """Default if nothing is set. The current player admits defeat."""
    DeclareVictory: DebugEndGame.EndResult.ValueType  # 2

    END_RESULT_FIELD_NUMBER: builtins.int
    end_result: global___DebugEndGame.EndResult.ValueType
    def __init__(
        self,
        *,
        end_result: global___DebugEndGame.EndResult.ValueType | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["end_result", b"end_result"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["end_result", b"end_result"]) -> None: ...

global___DebugEndGame = DebugEndGame

@typing_extensions.final
class DebugSetUnitValue(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _UnitValue:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _UnitValueEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[DebugSetUnitValue._UnitValue.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        Energy: DebugSetUnitValue._UnitValue.ValueType  # 1
        Life: DebugSetUnitValue._UnitValue.ValueType  # 2
        Shields: DebugSetUnitValue._UnitValue.ValueType  # 3

    class UnitValue(_UnitValue, metaclass=_UnitValueEnumTypeWrapper): ...
    Energy: DebugSetUnitValue.UnitValue.ValueType  # 1
    Life: DebugSetUnitValue.UnitValue.ValueType  # 2
    Shields: DebugSetUnitValue.UnitValue.ValueType  # 3

    UNIT_VALUE_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    UNIT_TAG_FIELD_NUMBER: builtins.int
    unit_value: global___DebugSetUnitValue.UnitValue.ValueType
    value: builtins.float
    unit_tag: builtins.int
    def __init__(
        self,
        *,
        unit_value: global___DebugSetUnitValue.UnitValue.ValueType | None = ...,
        value: builtins.float | None = ...,
        unit_tag: builtins.int | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["unit_tag", b"unit_tag", "unit_value", b"unit_value", "value", b"value"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["unit_tag", b"unit_tag", "unit_value", b"unit_value", "value", b"value"]) -> None: ...

global___DebugSetUnitValue = DebugSetUnitValue



from typing import ClassVar

from braintree.attribute_getter import AttributeGetter
from braintree.merchant_account.address_details import AddressDetails

class BusinessDetails(AttributeGetter):
    detail_list: ClassVar[list[str]]
    address_details: AddressDetails
    def __init__(self, attributes) -> None: ...



from _typeshed import Incomplete
from collections.abc import Callable, Mapping
from typing import Any, Generic, TypeVar, overload
from typing_extensions import ParamSpec, Self

_P = ParamSpec("_P")
_R = TypeVar("_R")
__all__ = ["_dispatch"]

class _dispatch(Generic[_P, _R]):
    __defaults__: Incomplete
    __kwdefaults__: Incomplete
    __module__: Incomplete
    __qualname__: Incomplete
    __wrapped__: Incomplete
    orig_func: Callable[_P, _R] | None
    name: str
    edge_attrs: dict[str, Any] | None
    node_attrs: dict[str, Any] | None
    preserve_edge_attrs: bool
    preserve_node_attrs: bool
    preserve_graph_attrs: bool
    optional_graphs: Incomplete
    list_graphs: Incomplete
    graphs: dict[str, int]
    backends: dict[str, Incomplete]
    # Incomplete: Ignoring the case where func=None returns a partial,
    # we only care about `_dispatch` used as a static-typing decorator
    def __new__(
        cls,
        func: Callable[_P, _R] | None = None,
        *,
        name: str | None = None,
        graphs: str | None | Mapping[str, int] = "G",
        edge_attrs: str | dict[str, Any] | None = None,
        node_attrs: str | dict[str, Any] | None = None,
        preserve_edge_attrs: bool = False,
        preserve_node_attrs: bool = False,
        preserve_graph_attrs: bool = False,
        preserve_all_attrs: bool = False,
    ) -> Self: ...
    @property
    def __doc__(self): ...
    @__doc__.setter
    def __doc__(self, val) -> None: ...
    @property
    def __signature__(self): ...
    # Type system limitations doesn't allow us to define this as it truly should.
    # But specifying backend with backend_kwargs isn't a common usecase anyway
    # and specifying backend as explicitely None is possible but not intended.
    # If this ever changes, update stubs/networkx/@tests/test_cases/check_dispatch_decorator.py
    @overload
    def __call__(self, *args: _P.args, **kwargs: _P.kwargs) -> _R: ...
    @overload
    def __call__(self, *args: Any, backend: str, **backend_kwargs: Any) -> _R: ...
    # @overload
    # def __call__(self, *args: _P.args, backend: None = None, **kwargs: _P.kwargs) -> _R: ...
    # @overload
    # def __call__(self, *args: _P.args, backend: str, **kwargs: _P.kwargs, **backend_kwargs: Any) -> _R: ...

    def __reduce__(self): ...



from _typeshed import StrOrBytesPath
from _typeshed.wsgi import StartResponse, WSGIApplication, WSGIEnvironment
from collections.abc import Iterable
from typing import IO, Any, Literal

from fanstatic.core import Library
from fanstatic.registry import LibraryRegistry
from webob import Request, Response
from webob.dec import wsgify
from webob.static import DirectoryApp, FileApp

MINUTE_IN_SECONDS: Literal[60]
HOUR_IN_SECONDS: Literal[3600]
DAY_IN_SECONDS: Literal[86400]
YEAR_IN_SECONDS: int
FOREVER: int

class BundleApp(FileApp):
    filenames: list[str]
    def __init__(self, rootpath: str, bundle: IO[bytes], filenames: Iterable[StrOrBytesPath]) -> None: ...
    @wsgify
    def __call__(self, req: Request) -> Response: ...

class LibraryPublisher(DirectoryApp):
    ignores: list[str]
    library: Library
    cached_apps: dict[str, FileApp]
    def __init__(self, library: Library) -> None: ...
    @wsgify
    def __call__(self, req: Request) -> Response: ...

class Publisher:
    registry: LibraryRegistry
    directory_publishers: dict[str, LibraryPublisher]
    def __init__(self, registry: LibraryRegistry) -> None: ...
    @wsgify
    def __call__(self, request: Request) -> Response: ...

class Delegator:
    app: WSGIApplication
    publisher: Publisher
    publisher_signature: str
    trigger: str
    def __init__(self, app: WSGIApplication, publisher: Publisher, publisher_signature: str = ...) -> None: ...
    def is_resource(self, request: Request) -> bool: ...
    def __call__(self, environ: WSGIEnvironment, start_response: StartResponse) -> Iterable[bytes]: ...

def make_publisher(global_config: Any) -> Publisher: ...



from collections.abc import Callable, MutableMapping
from typing import Any, Generic, Literal, TypeVar, overload
from typing_extensions import Self, TypeAlias

from webob.request import Request
from webob.response import Response

_T = TypeVar("_T")
_KT = TypeVar("_KT")
_VT = TypeVar("_VT")
_NoneLiteral = TypeVar("_NoneLiteral")
_Type: TypeAlias = type

class UpdateDict(dict[_KT, _VT]):
    updated: Callable[..., Any] | None
    updated_args: tuple[Any, ...] | None

class exists_property:
    prop: str
    type: str | None
    def __init__(self, prop: str, type: str | None = None) -> None: ...
    @overload
    def __get__(self, obj: None, type: _Type | None = None) -> Self: ...
    @overload
    def __get__(self, obj: Any, type: _Type | None = None) -> bool: ...
    def __set__(self, obj: Any, value: bool | None) -> None: ...
    def __delete__(self, obj: Any) -> None: ...

class value_property(Generic[_T, _NoneLiteral]):
    prop: str
    default: _T | None
    none: _NoneLiteral
    type: str | None
    @overload
    def __init__(self, prop: str, default: None = None, none: None = None, type: str | None = None) -> None: ...
    @overload
    def __init__(self, prop: str, default: _T, none: _NoneLiteral, type: str | None = None) -> None: ...
    @overload
    def __get__(self, obj: None, type: _Type | None = None) -> Self: ...
    @overload
    def __get__(self, obj: Any, type: _Type | None = None) -> _T | _NoneLiteral | None: ...
    def __set__(self, obj: Any, value: _T | Literal[True] | None) -> None: ...
    def __delete__(self, obj: Any) -> None: ...

class _IntValueProperty(value_property[int, _NoneLiteral]):
    def __set__(self, obj: Any, value: int | None) -> None: ...

class _BaseCacheControl:
    update_dict = UpdateDict
    properties: MutableMapping[str, Any]
    type: Literal["request", "response"] | None
    @classmethod
    @overload
    def parse(cls, header: str, updates_to: None = None, type: None = None) -> _AnyCacheControl: ...
    @classmethod
    @overload
    def parse(cls, header: str, updates_to: Request, type: Literal["request"]) -> _RequestCacheControl: ...
    @classmethod
    @overload
    def parse(cls, header: str, updates_to: Response, type: Literal["response"]) -> _ResponseCacheControl: ...

    no_cache: value_property[str, Literal["*"]]
    no_store: exists_property
    no_transform: exists_property
    max_age: _IntValueProperty[Literal[-1]]
    def copy(self) -> Self: ...

class _RequestCacheControl(_BaseCacheControl):
    type: Literal["request"]
    max_stale: _IntValueProperty[Literal["*"]]
    min_fresh: _IntValueProperty[None]
    only_if_cached: exists_property

class _ResponseCacheControl(_BaseCacheControl):
    type: Literal["response"]
    public: exists_property
    private: value_property[str, Literal["*"]]
    must_revalidate: exists_property
    proxy_revalidate: exists_property
    s_maxage: _IntValueProperty[None]
    s_max_age: _IntValueProperty[None]
    stale_while_revalidate: _IntValueProperty[None]
    stale_if_error: _IntValueProperty[None]

class _AnyCacheControl(_RequestCacheControl, _ResponseCacheControl):
    type: None  # type: ignore[assignment]

class CacheControl(_AnyCacheControl):
    @overload
    def __init__(self: _AnyCacheControl, properties: MutableMapping[str, Any], type: None) -> None: ...
    @overload
    def __init__(self: _RequestCacheControl, properties: MutableMapping[str, Any], type: Literal["request"]) -> None: ...
    @overload
    def __init__(self: _ResponseCacheControl, properties: MutableMapping[str, Any], type: Literal["response"]) -> None: ...

def serialize_cache_control(properties: MutableMapping[str, Any] | _BaseCacheControl) -> str: ...



from _typeshed import Incomplete

from networkx.utils.backends import _dispatch

__all__ = ["load_centrality", "edge_load_centrality"]

@_dispatch
def newman_betweenness_centrality(
    G, v: Incomplete | None = None, cutoff: Incomplete | None = None, normalized: bool = True, weight: Incomplete | None = None
): ...

load_centrality = newman_betweenness_centrality

@_dispatch
def edge_load_centrality(G, cutoff: bool = False): ...



from datetime import datetime, timedelta, tzinfo
from threading import Lock

date_helper: DateHelper | None
lock_: Lock

class DateHelper:
    timezone: tzinfo
    def __init__(self, timezone: tzinfo = ...) -> None: ...
    # This returns None in the implementation, but a datetime-compatible
    # object is monkey-patched in at runtime.
    def parse_date(self, date_string: str) -> datetime: ...
    def to_nanoseconds(self, delta: timedelta) -> int: ...
    def to_utc(self, value: datetime) -> datetime: ...

def get_date_helper() -> DateHelper: ...



from _typeshed import Incomplete
from typing import Any

from ...exceptions.exceptions import InvalidSamplingManifestError as InvalidSamplingManifestError
from .sampling_rule import SamplingRule as SamplingRule

local_sampling_rule: Any
SUPPORTED_RULE_VERSION: Any

class LocalSampler:
    def __init__(self, rules=...) -> None: ...
    def should_trace(self, sampling_req: Incomplete | None = None): ...
    def load_local_rules(self, rules) -> None: ...



from _typeshed import Incomplete
from pathlib import Path

from cffi import FFI

dir_path: Path
h_files: list[str]
h_source: list[str]
h_file: Path
f: Incomplete
C_HEADER_SRC: str
C_PREAMBLE: str
_: Path
libgit2_kw: dict[str, list[str]]
ffi: FFI



from datetime import date, timedelta
from typing import SupportsFloat, TypeVar, overload
from typing_extensions import Self, TypeAlias

# See #9817 for why we reexport this here
from ._common import weekday as weekday

_DateT = TypeVar("_DateT", bound=date)
# Work around attribute and type having the same name.
_Weekday: TypeAlias = weekday

MO: weekday
TU: weekday
WE: weekday
TH: weekday
FR: weekday
SA: weekday
SU: weekday

class relativedelta:
    years: int
    months: int
    days: int
    leapdays: int
    hours: int
    minutes: int
    seconds: int
    microseconds: int
    year: int | None
    month: int | None
    weekday: _Weekday | None
    day: int | None
    hour: int | None
    minute: int | None
    second: int | None
    microsecond: int | None
    def __init__(
        self,
        dt1: date | None = None,
        dt2: date | None = None,
        years: int | None = 0,
        months: int | None = 0,
        days: int | None = 0,
        leapdays: int | None = 0,
        weeks: int | None = 0,
        hours: int | None = 0,
        minutes: int | None = 0,
        seconds: int | None = 0,
        microseconds: int | None = 0,
        year: int | None = None,
        month: int | None = None,
        day: int | None = None,
        weekday: int | _Weekday | None = None,
        yearday: int | None = None,
        nlyearday: int | None = None,
        hour: int | None = None,
        minute: int | None = None,
        second: int | None = None,
        microsecond: int | None = None,
    ) -> None: ...
    @property
    def weeks(self) -> int: ...
    @weeks.setter
    def weeks(self, value: int) -> None: ...
    def normalized(self) -> Self: ...
    # TODO: use Union when mypy will handle it properly in overloaded operator
    # methods (#2129, #1442, #1264 in mypy)
    @overload
    def __add__(self, other: relativedelta) -> Self: ...
    @overload
    def __add__(self, other: timedelta) -> Self: ...
    @overload
    def __add__(self, other: _DateT) -> _DateT: ...
    @overload
    def __radd__(self, other: relativedelta) -> Self: ...
    @overload
    def __radd__(self, other: timedelta) -> Self: ...
    @overload
    def __radd__(self, other: _DateT) -> _DateT: ...
    @overload
    def __rsub__(self, other: relativedelta) -> Self: ...
    @overload
    def __rsub__(self, other: timedelta) -> Self: ...
    @overload
    def __rsub__(self, other: _DateT) -> _DateT: ...
    def __sub__(self, other: relativedelta) -> Self: ...
    def __neg__(self) -> Self: ...
    def __bool__(self) -> bool: ...
    def __nonzero__(self) -> bool: ...
    def __mul__(self, other: SupportsFloat) -> Self: ...
    def __rmul__(self, other: SupportsFloat) -> Self: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
    def __div__(self, other: SupportsFloat) -> Self: ...
    def __truediv__(self, other: SupportsFloat) -> Self: ...
    def __abs__(self) -> Self: ...
    def __hash__(self) -> int: ...



from _typeshed import Incomplete

from networkx.utils.backends import _dispatch

@_dispatch
def min_edge_cover(G, matching_algorithm: Incomplete | None = None): ...
@_dispatch
def is_edge_cover(G, cover): ...



from _typeshed import Incomplete
from collections.abc import Generator
from enum import Enum
from typing import Generic, NamedTuple, TypeVar

from networkx.utils.backends import _dispatch

_T = TypeVar("_T")

__all__ = ["read_gml", "parse_gml", "generate_gml", "write_gml"]

@_dispatch
def read_gml(path, label: str = "label", destringizer: Incomplete | None = None): ...
@_dispatch
def parse_gml(lines, label: str = "label", destringizer: Incomplete | None = None): ...

class Pattern(Enum):
    KEYS = 0
    REALS = 1
    INTS = 2
    STRINGS = 3
    DICT_START = 4
    DICT_END = 5
    COMMENT_WHITESPACE = 6

class Token(NamedTuple, Generic[_T]):
    category: Pattern
    value: _T
    line: int
    position: int

def generate_gml(G, stringizer: Incomplete | None = None) -> Generator[Incomplete, Incomplete, None]: ...
def write_gml(G, path, stringizer: Incomplete | None = None) -> None: ...



from _typeshed import Incomplete, Unused
from collections.abc import Iterable, Iterator, Mapping, Set as AbstractSet
from typing import Any, Generic, Literal, TypeVar, overload
from typing_extensions import Self

from networkx.classes.graph import Graph, _Edge, _NBunch, _Node

_D = TypeVar("_D")
_U = TypeVar("_U")

class NodeView(Mapping[_Node, dict[str, Any]], AbstractSet[_Node]):
    def __init__(self, graph: Graph[_Node]) -> None: ...
    def __len__(self) -> int: ...
    def __iter__(self) -> Iterator[_Node]: ...
    def __getitem__(self, n: _Node) -> dict[str, Any]: ...
    def __contains__(self, n: object) -> bool: ...
    @overload
    def __call__(self, data: Literal[False] = False, default: Incomplete | None = None) -> Iterator[_Node]: ...
    @overload
    def __call__(
        self, data: Literal[True] | str, default: Incomplete | None = None
    ) -> Iterator[tuple[_Node, dict[str, Any]]]: ...
    def data(self, data: bool | str = True, default: Incomplete | None = None) -> NodeDataView[_Node]: ...

class NodeDataView(AbstractSet[_Node]):
    def __init__(
        self, nodedict: Mapping[str, Incomplete], data: bool | str = False, default: Incomplete | None = None
    ) -> None: ...
    def __len__(self) -> int: ...
    def __iter__(self) -> Iterator[tuple[_Node, Incomplete]]: ...  # type: ignore[override]
    def __contains__(self, n: object) -> bool: ...
    def __getitem__(self, n: _Node): ...

class DiDegreeView(Generic[_Node]):
    def __init__(self, G: Graph[_Node], nbunch: _NBunch[_Node] = None, weight: None | bool | str = None) -> None: ...
    def __call__(self, nbunch: _NBunch[_Node] = None, weight: None | bool | str = None) -> DiDegreeView[_Node]: ...
    def __getitem__(self, n: _Node) -> float: ...
    def __iter__(self) -> Iterator[tuple[_Node, float]]: ...
    def __len__(self) -> int: ...

class DegreeView(DiDegreeView[_Node]): ...
class OutDegreeView(DiDegreeView[_Node]): ...
class InDegreeView(DiDegreeView[_Node]): ...
class MultiDegreeView(DiDegreeView[_Node]): ...
class DiMultiDegreeView(DiDegreeView[_Node]): ...
class InMultiDegreeView(DiDegreeView[_Node]): ...
class OutMultiDegreeView(DiDegreeView[_Node]): ...

class OutEdgeDataView(Generic[_Node, _D]):
    def __init__(
        self, viewer, nbunch: _NBunch[_Node] = None, data: bool = False, *, default: Incomplete | None = None
    ) -> None: ...
    def __len__(self) -> int: ...
    def __iter__(self) -> Iterator[_D]: ...
    def __contains__(self, e: _Edge[_Node]) -> bool: ...

class EdgeDataView(OutEdgeDataView[_Node, _D]): ...
class InEdgeDataView(OutEdgeDataView[_Node, _D]): ...

class OutMultiEdgeDataView(OutEdgeDataView[_Node, _D]):
    def __init__(
        self, viewer, nbunch: _NBunch[_Node] = None, data: bool = False, *, default: Incomplete | None = None, keys: bool = False
    ) -> None: ...

class MultiEdgeDataView(OutEdgeDataView[_Node, _D]): ...
class InMultiEdgeDataView(OutEdgeDataView[_Node, _D]): ...

class OutEdgeView(AbstractSet[Incomplete], Mapping[Incomplete, Incomplete], Generic[_Node]):
    def __init__(self, G: Graph[_Node]) -> None: ...
    def __len__(self) -> int: ...
    def __iter__(self) -> Iterator[tuple[_Node, _Node]]: ...
    def __contains__(self, e: _Edge[_Node]) -> bool: ...  # type: ignore[override]
    def __getitem__(self, e: _Edge[_Node]) -> dict[str, Any]: ...
    @overload
    def __call__(self, nbunch: None = None, data: Literal[False] = False, *, default: Unused = None) -> Self: ...
    @overload
    def __call__(
        self, nbunch: _Node | Iterable[_Node], data: Literal[False] = False, *, default: None = None
    ) -> OutEdgeDataView[_Node, tuple[_Node, _Node]]: ...
    @overload
    def __call__(
        self, nbunch: _NBunch[_Node], data: Literal[True], *, default: None = None
    ) -> OutEdgeDataView[_Node, tuple[_Node, _Node, dict[str, Incomplete]]]: ...
    @overload
    def __call__(
        self, nbunch: _NBunch[_Node] = None, *, data: Literal[True], default: None = None
    ) -> OutEdgeDataView[_Node, tuple[_Node, _Node, dict[str, Incomplete]]]: ...
    @overload
    def __call__(
        self, nbunch: _NBunch[_Node], data: str, *, default: _U | None = None
    ) -> OutEdgeDataView[_Node, tuple[_Node, _Node, _U]]: ...
    @overload
    def __call__(
        self, nbunch: _NBunch[_Node] = None, *, data: str, default: _U | None = None
    ) -> OutEdgeDataView[_Node, tuple[_Node, _Node, _U]]: ...
    @overload
    def data(self, data: Literal[False], default: Unused = None, nbunch: None = None) -> Self: ...
    @overload
    def data(
        self, data: Literal[True] = True, default: None = None, nbunch: _NBunch[_Node] = None
    ) -> OutEdgeDataView[_Node, tuple[_Node, _Node, dict[str, Incomplete]]]: ...
    @overload
    def data(
        self, data: str, default: _U | None = None, nbunch: _NBunch[_Node] = None
    ) -> OutEdgeDataView[_Node, tuple[_Node, _Node, _U]]: ...

class EdgeView(OutEdgeView[_Node]): ...
class InEdgeView(OutEdgeView[_Node]): ...

class OutMultiEdgeView(OutEdgeView[_Node]):
    @overload  # type: ignore[override]  # Has an additional `keys` keyword argument
    def __call__(
        self, nbunch: None = None, data: Literal[False] = False, *, default: Unused = None, keys: Literal[True]
    ) -> Self: ...
    @overload
    def __call__(
        self, nbunch: _NBunch[_Node], data: Literal[True], *, default: None = None, keys: bool = False
    ) -> OutMultiEdgeDataView[_Node, tuple[_Node, _Node, dict[str, Incomplete]]]: ...
    @overload
    def __call__(
        self, nbunch: _NBunch[_Node] = None, *, data: Literal[True], default: None = None, keys: bool = False
    ) -> OutMultiEdgeDataView[_Node, tuple[_Node, _Node, dict[str, Incomplete]]]: ...
    @overload
    def __call__(
        self, nbunch: _NBunch[_Node], data: str, *, default: _U | None = None, keys: bool = False
    ) -> OutMultiEdgeDataView[_Node, tuple[_Node, _Node, _U]]: ...
    @overload
    def __call__(
        self, nbunch: _NBunch[_Node] = None, *, data: str, default: _U | None = None, keys: bool = False
    ) -> OutMultiEdgeDataView[_Node, tuple[_Node, _Node, _U]]: ...
    @overload
    def data(self, data: Literal[False], default: Unused = None, nbunch: None = None, keys: Literal[False] = False) -> Self: ...
    @overload
    def data(
        self, data: Literal[True] = True, default: None = None, nbunch: _NBunch[_Node] = None, keys: bool = False
    ) -> OutMultiEdgeDataView[_Node, tuple[_Node, _Node, dict[str, Incomplete]]]: ...
    @overload
    def data(
        self, data: str, default: _U | None = None, nbunch: _NBunch[_Node] = None, keys: bool = False
    ) -> OutMultiEdgeDataView[_Node, tuple[_Node, _Node, _U]]: ...

class MultiEdgeView(OutMultiEdgeView[_Node]): ...
class InMultiEdgeView(OutMultiEdgeView[_Node]): ...



from typing import Final

MIN_ROW: Final = 0
MIN_COLUMN: Final = 0
MAX_COLUMN: Final = 16384
MAX_ROW: Final = 1048576

PACKAGE_PROPS: Final = "docProps"
PACKAGE_XL: Final = "xl"
PACKAGE_RELS: Final = "_rels"
PACKAGE_THEME: Final = "xl/theme"
PACKAGE_WORKSHEETS: Final = "xl/worksheets"
PACKAGE_CHARTSHEETS: Final = "xl/chartsheets"
PACKAGE_DRAWINGS: Final = "xl/drawings"
PACKAGE_CHARTS: Final = "xl/charts"
PACKAGE_IMAGES: Final = "xl/media"
PACKAGE_WORKSHEET_RELS: Final = "xl/worksheets/_rels"
PACKAGE_CHARTSHEETS_RELS: Final = "xl/chartsheets/_rels"
PACKAGE_PIVOT_TABLE: Final = "xl/pivotTables"
PACKAGE_PIVOT_CACHE: Final = "xl/pivotCache"

ARC_CONTENT_TYPES: Final = "[Content_Types].xml"
ARC_ROOT_RELS: Final = "_rels/.rels"
ARC_WORKBOOK_RELS: Final = "xl/_rels/workbook.xml.rels"
ARC_CORE: Final = "docProps/core.xml"
ARC_APP: Final = "docProps/app.xml"
ARC_CUSTOM: Final = "docProps/custom.xml"
ARC_WORKBOOK: Final = "xl/workbook.xml"
ARC_STYLE: Final = "xl/styles.xml"
ARC_THEME: Final = "xl/theme/theme1.xml"
ARC_SHARED_STRINGS: Final = "xl/sharedStrings.xml"
ARC_CUSTOM_UI: Final = "customUI/customUI.xml"

DCORE_NS: Final = "http://purl.org/dc/elements/1.1/"
DCTERMS_NS: Final = "http://purl.org/dc/terms/"
DCTERMS_PREFIX: Final = "dcterms"

DOC_NS: Final[str]
REL_NS: Final[str]
COMMENTS_NS: Final[str]
IMAGE_NS: Final[str]
VML_NS: Final[str]
VTYPES_NS: Final[str]
XPROPS_NS: Final[str]
CUSTPROPS_NS: Final[str]
EXTERNAL_LINK_NS: Final[str]

CPROPS_FMTID: Final = "{D5CDD505-2E9C-101B-9397-08002B2CF9AE}"

PKG_NS: Final = "http://schemas.openxmlformats.org/package/2006/"
PKG_REL_NS: Final[str]
COREPROPS_NS: Final[str]
CONTYPES_NS: Final[str]

XSI_NS: Final = "http://www.w3.org/2001/XMLSchema-instance"
XML_NS: Final = "http://www.w3.org/XML/1998/namespace"
SHEET_MAIN_NS: Final[str]

CHART_NS: Final[str]
DRAWING_NS: Final[str]
SHEET_DRAWING_NS: Final[str]
CHART_DRAWING_NS: Final[str]

CUSTOMUI_NS: Final[str]

NAMESPACES: Final[dict[str, str]]

WORKBOOK_MACRO: Final = "application/vnd.ms-excel.%s.macroEnabled.main+xml"
WORKBOOK: Final[str]
SPREADSHEET: Final[str]
SHARED_STRINGS: Final[str]
EXTERNAL_LINK: Final[str]
WORKSHEET_TYPE: Final[str]
COMMENTS_TYPE: Final[str]
STYLES_TYPE: Final[str]
CHARTSHEET_TYPE: Final[str]
DRAWING_TYPE: Final[str]
CHART_TYPE: Final[str]
CHARTSHAPE_TYPE: Final[str]
THEME_TYPE: Final[str]
CPROPS_TYPE: Final[str]
XLTM: Final[str]
XLSM: Final[str]
XLTX: Final[str]
XLSX: Final[str]

EXT_TYPES: Final[dict[str, str]]

CTRL: Final = "application/vnd.ms-excel.controlproperties+xml"
ACTIVEX: Final = "application/vnd.ms-office.activeX+xml"
VBA: Final = "application/vnd.ms-office.vbaProject"



from typing import ClassVar

from .core import UnitedStates

class NewMexico(UnitedStates):
    include_thanksgiving_friday: ClassVar[bool]
    thanksgiving_friday_label: ClassVar[str]
    include_federal_presidents_day: ClassVar[bool]



import threading
from collections.abc import Iterator
from types import TracebackType
from typing import Literal, Protocol
from typing_extensions import Self

__version__: str

class _Stream(Protocol):
    def isatty(self) -> bool: ...
    def flush(self) -> None: ...
    def write(self, s: str, /) -> int: ...

class Spinner:
    spinner_cycle: Iterator[str]
    disable: bool
    beep: bool
    force: bool
    stream: _Stream
    stop_running: threading.Event | None
    spin_thread: threading.Thread | None
    def __init__(self, beep: bool = False, disable: bool = False, force: bool = False, stream: _Stream = ...) -> None: ...
    def start(self) -> None: ...
    def stop(self) -> None: ...
    def init_spin(self) -> None: ...
    def __enter__(self) -> Self: ...
    def __exit__(
        self, exc_type: type[BaseException] | None, exc_val: BaseException | None, exc_tb: TracebackType | None
    ) -> Literal[False]: ...

def spinner(beep: bool = False, disable: bool = False, force: bool = False, stream: _Stream = ...) -> Spinner: ...



import queue
import sys
import threading
from _typeshed import SupportsKeysAndGetItem, SupportsRichComparison, SupportsRichComparisonT
from collections.abc import Callable, Iterable, Iterator, Mapping, MutableMapping, MutableSequence, Sequence
from types import TracebackType
from typing import Any, AnyStr, ClassVar, Generic, SupportsIndex, TypeVar, overload
from typing_extensions import Self, TypeAlias

from .connection import Connection
from .context import BaseContext
from .shared_memory import _SLT, ShareableList as _ShareableList, SharedMemory as _SharedMemory

__all__ = ["BaseManager", "SyncManager", "BaseProxy", "Token", "SharedMemoryManager"]

if sys.version_info >= (3, 9):
    from types import GenericAlias

_T = TypeVar("_T")
_KT = TypeVar("_KT")
_VT = TypeVar("_VT")

class Namespace:
    def __init__(self, **kwds: Any) -> None: ...
    def __getattr__(self, name: str, /) -> Any: ...
    def __setattr__(self, name: str, value: Any, /) -> None: ...

_Namespace: TypeAlias = Namespace

class Token:
    typeid: str | bytes | None
    address: tuple[str | bytes, int]
    id: str | bytes | int | None
    def __init__(self, typeid: bytes | str | None, address: tuple[str | bytes, int], id: str | bytes | int | None) -> None: ...
    def __getstate__(self) -> tuple[str | bytes | None, tuple[str | bytes, int], str | bytes | int | None]: ...
    def __setstate__(self, state: tuple[str | bytes | None, tuple[str | bytes, int], str | bytes | int | None]) -> None: ...

class BaseProxy:
    _address_to_local: dict[Any, Any]
    _mutex: Any
    def __init__(
        self,
        token: Any,
        serializer: str,
        manager: Any = None,
        authkey: AnyStr | None = None,
        exposed: Any = None,
        incref: bool = True,
        manager_owned: bool = False,
    ) -> None: ...
    def __deepcopy__(self, memo: Any | None) -> Any: ...
    def _callmethod(self, methodname: str, args: tuple[Any, ...] = (), kwds: dict[Any, Any] = {}) -> None: ...
    def _getvalue(self) -> Any: ...
    def __reduce__(self) -> tuple[Any, tuple[Any, Any, str, dict[Any, Any]]]: ...

class ValueProxy(BaseProxy, Generic[_T]):
    def get(self) -> _T: ...
    def set(self, value: _T) -> None: ...
    value: _T
    if sys.version_info >= (3, 9):
        def __class_getitem__(cls, item: Any) -> GenericAlias: ...

class DictProxy(BaseProxy, MutableMapping[_KT, _VT]):
    __builtins__: ClassVar[dict[str, Any]]
    def __len__(self) -> int: ...
    def __getitem__(self, key: _KT, /) -> _VT: ...
    def __setitem__(self, key: _KT, value: _VT, /) -> None: ...
    def __delitem__(self, key: _KT, /) -> None: ...
    def __iter__(self) -> Iterator[_KT]: ...
    def copy(self) -> dict[_KT, _VT]: ...
    @overload  # type: ignore[override]
    def get(self, key: _KT, /) -> _VT | None: ...
    @overload
    def get(self, key: _KT, default: _VT, /) -> _VT: ...
    @overload
    def get(self, key: _KT, default: _T, /) -> _VT | _T: ...
    @overload
    def pop(self, key: _KT, /) -> _VT: ...
    @overload
    def pop(self, key: _KT, default: _VT, /) -> _VT: ...
    @overload
    def pop(self, key: _KT, default: _T, /) -> _VT | _T: ...
    def keys(self) -> list[_KT]: ...  # type: ignore[override]
    def items(self) -> list[tuple[_KT, _VT]]: ...  # type: ignore[override]
    def values(self) -> list[_VT]: ...  # type: ignore[override]

class BaseListProxy(BaseProxy, MutableSequence[_T]):
    __builtins__: ClassVar[dict[str, Any]]
    def __len__(self) -> int: ...
    def __add__(self, x: list[_T], /) -> list[_T]: ...
    def __delitem__(self, i: SupportsIndex | slice, /) -> None: ...
    @overload
    def __getitem__(self, i: SupportsIndex, /) -> _T: ...
    @overload
    def __getitem__(self, s: slice, /) -> list[_T]: ...
    @overload
    def __setitem__(self, i: SupportsIndex, o: _T, /) -> None: ...
    @overload
    def __setitem__(self, s: slice, o: Iterable[_T], /) -> None: ...
    def __mul__(self, n: SupportsIndex, /) -> list[_T]: ...
    def __rmul__(self, n: SupportsIndex, /) -> list[_T]: ...
    def __reversed__(self) -> Iterator[_T]: ...
    def append(self, object: _T, /) -> None: ...
    def extend(self, iterable: Iterable[_T], /) -> None: ...
    def pop(self, index: SupportsIndex = ..., /) -> _T: ...
    def index(self, value: _T, start: SupportsIndex = ..., stop: SupportsIndex = ..., /) -> int: ...
    def count(self, value: _T, /) -> int: ...
    def insert(self, index: SupportsIndex, object: _T, /) -> None: ...
    def remove(self, value: _T, /) -> None: ...
    # Use BaseListProxy[SupportsRichComparisonT] for the first overload rather than [SupportsRichComparison]
    # to work around invariance
    @overload
    def sort(self: BaseListProxy[SupportsRichComparisonT], *, key: None = None, reverse: bool = ...) -> None: ...
    @overload
    def sort(self, *, key: Callable[[_T], SupportsRichComparison], reverse: bool = ...) -> None: ...

class ListProxy(BaseListProxy[_T]):
    def __iadd__(self, value: Iterable[_T], /) -> Self: ...  # type: ignore[override]
    def __imul__(self, value: SupportsIndex, /) -> Self: ...  # type: ignore[override]

# Returned by BaseManager.get_server()
class Server:
    address: Any
    def __init__(
        self, registry: dict[str, tuple[Callable[..., Any], Any, Any, Any]], address: Any, authkey: bytes, serializer: str
    ) -> None: ...
    def serve_forever(self) -> None: ...
    def accept_connection(self, c: Connection, name: str) -> None: ...

class BaseManager:
    if sys.version_info >= (3, 11):
        def __init__(
            self,
            address: Any | None = None,
            authkey: bytes | None = None,
            serializer: str = "pickle",
            ctx: BaseContext | None = None,
            *,
            shutdown_timeout: float = 1.0,
        ) -> None: ...
    else:
        def __init__(
            self,
            address: Any | None = None,
            authkey: bytes | None = None,
            serializer: str = "pickle",
            ctx: BaseContext | None = None,
        ) -> None: ...

    def get_server(self) -> Server: ...
    def connect(self) -> None: ...
    def start(self, initializer: Callable[..., object] | None = None, initargs: Iterable[Any] = ()) -> None: ...
    def shutdown(self) -> None: ...  # only available after start() was called
    def join(self, timeout: float | None = None) -> None: ...  # undocumented
    @property
    def address(self) -> Any: ...
    @classmethod
    def register(
        cls,
        typeid: str,
        callable: Callable[..., object] | None = None,
        proxytype: Any = None,
        exposed: Sequence[str] | None = None,
        method_to_typeid: Mapping[str, str] | None = None,
        create_method: bool = True,
    ) -> None: ...
    def __enter__(self) -> Self: ...
    def __exit__(
        self, exc_type: type[BaseException] | None, exc_val: BaseException | None, exc_tb: TracebackType | None
    ) -> None: ...

class SyncManager(BaseManager):
    def BoundedSemaphore(self, value: Any = ...) -> threading.BoundedSemaphore: ...
    def Condition(self, lock: Any = ...) -> threading.Condition: ...
    def Event(self) -> threading.Event: ...
    def Lock(self) -> threading.Lock: ...
    def Namespace(self) -> _Namespace: ...
    def Queue(self, maxsize: int = ...) -> queue.Queue[Any]: ...
    def RLock(self) -> threading.RLock: ...
    def Semaphore(self, value: Any = ...) -> threading.Semaphore: ...
    def Array(self, typecode: Any, sequence: Sequence[_T]) -> Sequence[_T]: ...
    def Value(self, typecode: Any, value: _T) -> ValueProxy[_T]: ...
    # Overloads are copied from builtins.dict.__init__
    @overload
    def dict(self) -> DictProxy[Any, Any]: ...
    @overload
    def dict(self, **kwargs: _VT) -> DictProxy[str, _VT]: ...
    @overload
    def dict(self, map: SupportsKeysAndGetItem[_KT, _VT], /) -> DictProxy[_KT, _VT]: ...
    @overload
    def dict(self, map: SupportsKeysAndGetItem[str, _VT], /, **kwargs: _VT) -> DictProxy[str, _VT]: ...
    @overload
    def dict(self, iterable: Iterable[tuple[_KT, _VT]], /) -> DictProxy[_KT, _VT]: ...
    @overload
    def dict(self, iterable: Iterable[tuple[str, _VT]], /, **kwargs: _VT) -> DictProxy[str, _VT]: ...
    @overload
    def dict(self, iterable: Iterable[list[str]], /) -> DictProxy[str, str]: ...
    @overload
    def dict(self, iterable: Iterable[list[bytes]], /) -> DictProxy[bytes, bytes]: ...
    @overload
    def list(self, sequence: Sequence[_T], /) -> ListProxy[_T]: ...
    @overload
    def list(self) -> ListProxy[Any]: ...

class RemoteError(Exception): ...
class SharedMemoryServer(Server): ...

class SharedMemoryManager(BaseManager):
    def get_server(self) -> SharedMemoryServer: ...
    def SharedMemory(self, size: int) -> _SharedMemory: ...
    def ShareableList(self, sequence: Iterable[_SLT] | None) -> _ShareableList[_SLT]: ...
    def __del__(self) -> None: ...



from typing import Final

XK_leftradical: Final = 0x8A1
XK_topleftradical: Final = 0x8A2
XK_horizconnector: Final = 0x8A3
XK_topintegral: Final = 0x8A4
XK_botintegral: Final = 0x8A5
XK_vertconnector: Final = 0x8A6
XK_topleftsqbracket: Final = 0x8A7
XK_botleftsqbracket: Final = 0x8A8
XK_toprightsqbracket: Final = 0x8A9
XK_botrightsqbracket: Final = 0x8AA
XK_topleftparens: Final = 0x8AB
XK_botleftparens: Final = 0x8AC
XK_toprightparens: Final = 0x8AD
XK_botrightparens: Final = 0x8AE
XK_leftmiddlecurlybrace: Final = 0x8AF
XK_rightmiddlecurlybrace: Final = 0x8B0
XK_topleftsummation: Final = 0x8B1
XK_botleftsummation: Final = 0x8B2
XK_topvertsummationconnector: Final = 0x8B3
XK_botvertsummationconnector: Final = 0x8B4
XK_toprightsummation: Final = 0x8B5
XK_botrightsummation: Final = 0x8B6
XK_rightmiddlesummation: Final = 0x8B7
XK_lessthanequal: Final = 0x8BC
XK_notequal: Final = 0x8BD
XK_greaterthanequal: Final = 0x8BE
XK_integral: Final = 0x8BF
XK_therefore: Final = 0x8C0
XK_variation: Final = 0x8C1
XK_infinity: Final = 0x8C2
XK_nabla: Final = 0x8C5
XK_approximate: Final = 0x8C8
XK_similarequal: Final = 0x8C9
XK_ifonlyif: Final = 0x8CD
XK_implies: Final = 0x8CE
XK_identical: Final = 0x8CF
XK_radical: Final = 0x8D6
XK_includedin: Final = 0x8DA
XK_includes: Final = 0x8DB
XK_intersection: Final = 0x8DC
XK_union: Final = 0x8DD
XK_logicaland: Final = 0x8DE
XK_logicalor: Final = 0x8DF
XK_partialderivative: Final = 0x8EF
XK_function: Final = 0x8F6
XK_leftarrow: Final = 0x8FB
XK_uparrow: Final = 0x8FC
XK_rightarrow: Final = 0x8FD
XK_downarrow: Final = 0x8FE



CSI: str
OSC: str
BEL: str

def code_to_chars(code: int) -> str: ...
def set_title(title: str) -> str: ...
def clear_screen(mode: int = 2) -> str: ...
def clear_line(mode: int = 2) -> str: ...

class AnsiCodes:
    def __init__(self) -> None: ...

class AnsiCursor:
    def UP(self, n: int = 1) -> str: ...
    def DOWN(self, n: int = 1) -> str: ...
    def FORWARD(self, n: int = 1) -> str: ...
    def BACK(self, n: int = 1) -> str: ...
    def POS(self, x: int = 1, y: int = 1) -> str: ...

# All attributes in the following classes are string in instances and int in the class.
# We use str since that is the common case for users.
class AnsiFore(AnsiCodes):
    BLACK: str
    RED: str
    GREEN: str
    YELLOW: str
    BLUE: str
    MAGENTA: str
    CYAN: str
    WHITE: str
    RESET: str
    LIGHTBLACK_EX: str
    LIGHTRED_EX: str
    LIGHTGREEN_EX: str
    LIGHTYELLOW_EX: str
    LIGHTBLUE_EX: str
    LIGHTMAGENTA_EX: str
    LIGHTCYAN_EX: str
    LIGHTWHITE_EX: str

class AnsiBack(AnsiCodes):
    BLACK: str
    RED: str
    GREEN: str
    YELLOW: str
    BLUE: str
    MAGENTA: str
    CYAN: str
    WHITE: str
    RESET: str
    LIGHTBLACK_EX: str
    LIGHTRED_EX: str
    LIGHTGREEN_EX: str
    LIGHTYELLOW_EX: str
    LIGHTBLUE_EX: str
    LIGHTMAGENTA_EX: str
    LIGHTCYAN_EX: str
    LIGHTWHITE_EX: str

class AnsiStyle(AnsiCodes):
    BRIGHT: str
    DIM: str
    NORMAL: str
    RESET_ALL: str

Fore: AnsiFore
Back: AnsiBack
Style: AnsiStyle
Cursor: AnsiCursor



from _typeshed import Incomplete

from influxdb_client.service._base_service import _BaseService

class MetricsService(_BaseService):
    def __init__(self, api_client: Incomplete | None = None) -> None: ...
    def get_metrics(self, **kwargs): ...
    def get_metrics_with_http_info(self, **kwargs): ...
    async def get_metrics_async(self, **kwargs): ...



import abc
from _typeshed import Incomplete

from qrcode.image.styledpil import StyledPilImage
from qrcode.image.styles.moduledrawers.base import QRModuleDrawer
from qrcode.main import ActiveWithNeighbors

ANTIALIASING_FACTOR: int

class StyledPilQRModuleDrawer(QRModuleDrawer, metaclass=abc.ABCMeta):
    img: StyledPilImage

class SquareModuleDrawer(StyledPilQRModuleDrawer):
    imgDraw: Incomplete
    def initialize(self, *args, **kwargs) -> None: ...
    def drawrect(self, box, is_active: bool): ...

class GappedSquareModuleDrawer(StyledPilQRModuleDrawer):
    size_ratio: Incomplete
    def __init__(self, size_ratio: float = 0.8) -> None: ...
    imgDraw: Incomplete
    delta: Incomplete
    def initialize(self, *args, **kwargs) -> None: ...
    def drawrect(self, box, is_active: bool): ...

class CircleModuleDrawer(StyledPilQRModuleDrawer):
    circle: Incomplete
    def initialize(self, *args, **kwargs) -> None: ...
    def drawrect(self, box, is_active: bool): ...

class RoundedModuleDrawer(StyledPilQRModuleDrawer):
    needs_neighbors: bool
    radius_ratio: Incomplete
    def __init__(self, radius_ratio: int = 1) -> None: ...
    corner_width: Incomplete
    def initialize(self, *args, **kwargs) -> None: ...
    SQUARE: Incomplete
    NW_ROUND: Incomplete
    SW_ROUND: Incomplete
    SE_ROUND: Incomplete
    NE_ROUND: Incomplete
    def setup_corners(self) -> None: ...
    def drawrect(self, box: list[list[int]], is_active: ActiveWithNeighbors): ...

class VerticalBarsDrawer(StyledPilQRModuleDrawer):
    needs_neighbors: bool
    horizontal_shrink: Incomplete
    def __init__(self, horizontal_shrink: float = 0.8) -> None: ...
    half_height: Incomplete
    delta: Incomplete
    def initialize(self, *args, **kwargs) -> None: ...
    SQUARE: Incomplete
    ROUND_TOP: Incomplete
    ROUND_BOTTOM: Incomplete
    def setup_edges(self) -> None: ...
    def drawrect(self, box, is_active: ActiveWithNeighbors): ...

class HorizontalBarsDrawer(StyledPilQRModuleDrawer):
    needs_neighbors: bool
    vertical_shrink: Incomplete
    def __init__(self, vertical_shrink: float = 0.8) -> None: ...
    half_width: Incomplete
    delta: Incomplete
    def initialize(self, *args, **kwargs) -> None: ...
    SQUARE: Incomplete
    ROUND_LEFT: Incomplete
    ROUND_RIGHT: Incomplete
    def setup_edges(self) -> None: ...
    def drawrect(self, box, is_active: ActiveWithNeighbors): ...



from _typeshed import Incomplete
from typing import Any

from .asynchronous import AsyncStrategy
from .mockBase import MockBaseStrategy

class MockAsyncStrategy(MockBaseStrategy, AsyncStrategy):
    def __init__(self, ldap_connection) -> None: ...
    def post_send_search(self, payload): ...
    bound: Any
    def post_send_single_response(self, payload): ...
    def get_response(self, message_id, timeout: Incomplete | None = None, get_request: bool = False): ...



from _typeshed import Incomplete
from collections.abc import Generator

from networkx.utils.backends import _dispatch

@_dispatch
def edge_dfs(
    G, source: Incomplete | None = None, orientation: Incomplete | None = None
) -> Generator[Incomplete, None, Incomplete]: ...



from _typeshed import Incomplete

from hvac.api.system_backend.system_backend_mixin import SystemBackendMixin

class Auth(SystemBackendMixin):
    def list_auth_methods(self): ...
    def enable_auth_method(
        self,
        method_type,
        description: Incomplete | None = None,
        config: Incomplete | None = None,
        plugin_name: Incomplete | None = None,
        local: bool = False,
        path: Incomplete | None = None,
        **kwargs,
    ): ...
    def disable_auth_method(self, path): ...
    def read_auth_method_tuning(self, path): ...
    def tune_auth_method(
        self,
        path,
        default_lease_ttl: Incomplete | None = None,
        max_lease_ttl: Incomplete | None = None,
        description: Incomplete | None = None,
        audit_non_hmac_request_keys: Incomplete | None = None,
        audit_non_hmac_response_keys: Incomplete | None = None,
        listing_visibility: Incomplete | None = None,
        passthrough_request_headers: Incomplete | None = None,
        **kwargs,
    ): ...



from _typeshed import Incomplete
from typing import Any

DOCUMENT: Any
DOCTYPE: Any
TEXT: Any
ELEMENT: Any
COMMENT: Any
ENTITY: Any
UNKNOWN: str

class TreeWalker:
    tree: Any
    def __init__(self, tree) -> None: ...
    def __iter__(self): ...
    def error(self, msg): ...
    def emptyTag(self, namespace, name, attrs, hasChildren: bool = False) -> None: ...
    def startTag(self, namespace, name, attrs): ...
    def endTag(self, namespace, name): ...
    def text(self, data) -> None: ...
    def comment(self, data): ...
    def doctype(self, name, publicId: Incomplete | None = None, systemId: Incomplete | None = None): ...
    def entity(self, name): ...
    def unknown(self, nodeType): ...

class NonRecursiveTreeWalker(TreeWalker):
    def getNodeDetails(self, node) -> None: ...
    def getFirstChild(self, node) -> None: ...
    def getNextSibling(self, node) -> None: ...
    def getParentNode(self, node) -> None: ...
    def __iter__(self): ...



from _typeshed import ConvertibleToInt, Incomplete
from typing import ClassVar, Literal, overload
from typing_extensions import TypeAlias

from openpyxl.descriptors.base import Bool, Integer, Set, String, _ConvertibleToBool
from openpyxl.descriptors.serialisable import Serialisable

_WebPublishItemSourceType: TypeAlias = Literal[
    "sheet", "printArea", "autoFilter", "range", "chart", "pivotTable", "query", "label"
]

class WebPublishItem(Serialisable):
    tagname: ClassVar[str]
    id: Integer[Literal[False]]
    divId: String[Literal[False]]
    sourceType: Set[_WebPublishItemSourceType]
    sourceRef: String[Literal[False]]
    sourceObject: String[Literal[True]]
    destinationFile: String[Literal[False]]
    title: String[Literal[True]]
    autoRepublish: Bool[Literal[True]]
    @overload
    def __init__(
        self,
        id: ConvertibleToInt,
        divId: str,
        sourceType: _WebPublishItemSourceType,
        sourceRef: str,
        sourceObject: str | None = None,
        *,
        destinationFile: str,
        title: str | None = None,
        autoRepublish: _ConvertibleToBool | None = None,
    ) -> None: ...
    @overload
    def __init__(
        self,
        id: ConvertibleToInt,
        divId: str,
        sourceType: _WebPublishItemSourceType,
        sourceRef: str,
        sourceObject: str | None,
        destinationFile: str,
        title: str | None = None,
        autoRepublish: _ConvertibleToBool | None = None,
    ) -> None: ...

class WebPublishItems(Serialisable):
    tagname: ClassVar[str]
    count: Integer[Literal[True]]
    webPublishItem: Incomplete
    __elements__: ClassVar[tuple[str, ...]]
    def __init__(self, count: ConvertibleToInt | None = None, webPublishItem: Incomplete | None = None) -> None: ...



from _typeshed import Incomplete

from antlr4.Token import Token as Token

class InputStream:
    name: str
    strdata: Incomplete
    data: Incomplete
    def __init__(self, data: str) -> None: ...
    @property
    def index(self): ...
    @property
    def size(self): ...
    def reset(self) -> None: ...
    def consume(self) -> None: ...
    def LA(self, offset: int): ...
    def LT(self, offset: int): ...
    def mark(self): ...
    def release(self, marker: int): ...
    def seek(self, _index: int): ...
    def getText(self, start: int, stop: int): ...



# flake8-2020 has type annotations, but PEP 561 states:
# This PEP does not support distributing typing information as part of module-only distributions or single-file modules within namespace packages.
# Therefore typeshed is the best place.

import ast
from collections.abc import Generator
from typing import Any, ClassVar

YTT101: str
YTT102: str
YTT103: str
YTT201: str
YTT202: str
YTT203: str
YTT204: str
YTT301: str
YTT302: str
YTT303: str

class Visitor(ast.NodeVisitor): ...

class Plugin:
    name: ClassVar[str]
    version: ClassVar[str]
    def __init__(self, tree: ast.AST) -> None: ...
    def run(self) -> Generator[tuple[int, int, str, type[Any]], None, None]: ...



from collections.abc import Callable
from types import TracebackType
from typing import Any, Literal

from gevent._abstract_linkable import AbstractLinkable
from gevent.hub import Hub

__all__ = ["Semaphore", "BoundedSemaphore", "DummySemaphore", "RLock"]

class Semaphore(AbstractLinkable):
    counter: int
    def __init__(self, value: int = 1, hub: Hub | None = None) -> None: ...
    def acquire(self, blocking: bool = True, timeout: float | None = None) -> bool: ...
    def locked(self) -> bool: ...
    def ready(self) -> bool: ...
    def release(self) -> int: ...
    def wait(self, timeout: float | None = None) -> int: ...
    def __enter__(self) -> None: ...
    def __exit__(self, t: type[BaseException] | None, v: BaseException | None, tb: TracebackType | None) -> None: ...

class BoundedSemaphore(Semaphore): ...

class DummySemaphore:
    def __init__(self, value: int | None = None) -> None: ...
    def locked(self) -> Literal[False]: ...
    def ready(self) -> Literal[True]: ...
    def release(self) -> None: ...
    def rawlink(self, callback: Callable[[Any], object]) -> None: ...
    def unlink(self, callback: Callable[[Any], object]) -> None: ...
    def wait(self, timeout: float | None = None) -> Literal[1]: ...
    def acquire(self, blocking: bool = True, timeout: float | None = None) -> Literal[True]: ...
    def __enter__(self) -> None: ...
    def __exit__(self, typ: type[BaseException] | None, val: BaseException | None, tb: TracebackType | None) -> None: ...

class RLock:
    def __init__(self, hub: Hub | None = None) -> None: ...
    def acquire(self, blocking: bool = True, timeout: float | None = None) -> bool: ...
    def __enter__(self) -> bool: ...
    def release(self) -> None: ...
    def __exit__(self, typ: type[BaseException] | None, val: BaseException | None, tb: TracebackType | None) -> None: ...



from _typeshed import Incomplete
from typing import ClassVar

from ..core import WesternCalendar

class Estonia(WesternCalendar):
    include_good_friday: ClassVar[bool]
    include_easter_sunday: ClassVar[bool]
    include_whit_sunday: ClassVar[bool]
    whit_sunday_label: ClassVar[str]
    include_christmas_eve: ClassVar[bool]
    include_christmas: ClassVar[bool]
    include_boxing_day: ClassVar[bool]
    boxing_day_label: ClassVar[str]
    FIXED_HOLIDAYS: Incomplete



from _typeshed import Incomplete
from typing import Final

from braintree.account_updater_daily_report import AccountUpdaterDailyReport
from braintree.connected_merchant_paypal_status_changed import ConnectedMerchantPayPalStatusChanged
from braintree.connected_merchant_status_transitioned import ConnectedMerchantStatusTransitioned
from braintree.disbursement import Disbursement
from braintree.dispute import Dispute
from braintree.granted_payment_instrument_update import GrantedPaymentInstrumentUpdate
from braintree.local_payment_completed import LocalPaymentCompleted
from braintree.local_payment_expired import LocalPaymentExpired
from braintree.local_payment_funded import LocalPaymentFunded
from braintree.local_payment_reversed import LocalPaymentReversed
from braintree.merchant_account import MerchantAccount
from braintree.oauth_access_revocation import OAuthAccessRevocation
from braintree.partner_merchant import PartnerMerchant
from braintree.payment_method_customer_data_updated_metadata import PaymentMethodCustomerDataUpdatedMetadata
from braintree.resource import Resource
from braintree.revoked_payment_method_metadata import RevokedPaymentMethodMetadata
from braintree.subscription import Subscription
from braintree.transaction import Transaction
from braintree.transaction_review import TransactionReview
from braintree.validation_error_collection import ValidationErrorCollection

class WebhookNotification(Resource):
    class Kind:
        AccountUpdaterDailyReport: Final = "account_updater_daily_report"
        Check: Final = "check"
        ConnectedMerchantPayPalStatusChanged: Final = "connected_merchant_paypal_status_changed"
        ConnectedMerchantStatusTransitioned: Final = "connected_merchant_status_transitioned"
        Disbursement: Final = "disbursement"
        DisbursementException: Final = "disbursement_exception"
        DisputeAccepted: Final = "dispute_accepted"
        DisputeAutoAccepted: Final = "dispute_auto_accepted"
        DisputeDisputed: Final = "dispute_disputed"
        DisputeExpired: Final = "dispute_expired"
        DisputeLost: Final = "dispute_lost"
        DisputeOpened: Final = "dispute_opened"
        DisputeUnderReview: Final = "dispute_under_review"
        DisputeWon: Final = "dispute_won"
        GrantedPaymentMethodRevoked: Final = "granted_payment_method_revoked"
        GrantorUpdatedGrantedPaymentMethod: Final = "grantor_updated_granted_payment_method"
        LocalPaymentCompleted: Final = "local_payment_completed"
        LocalPaymentExpired: Final = "local_payment_expired"
        LocalPaymentFunded: Final = "local_payment_funded"
        LocalPaymentReversed: Final = "local_payment_reversed"
        OAuthAccessRevoked: Final = "oauth_access_revoked"
        PartnerMerchantConnected: Final = "partner_merchant_connected"
        PartnerMerchantDeclined: Final = "partner_merchant_declined"
        PartnerMerchantDisconnected: Final = "partner_merchant_disconnected"
        PaymentMethodCustomerDataUpdated: Final = "payment_method_customer_data_updated"
        PaymentMethodRevokedByCustomer: Final = "payment_method_revoked_by_customer"
        RecipientUpdatedGrantedPaymentMethod: Final = "recipient_updated_granted_payment_method"
        SubMerchantAccountApproved: Final = "sub_merchant_account_approved"
        SubMerchantAccountDeclined: Final = "sub_merchant_account_declined"
        SubscriptionBillingSkipped: Final = "subscription_billing_skipped"
        SubscriptionCanceled: Final = "subscription_canceled"
        SubscriptionChargedSuccessfully: Final = "subscription_charged_successfully"
        SubscriptionChargedUnsuccessfully: Final = "subscription_charged_unsuccessfully"
        SubscriptionExpired: Final = "subscription_expired"
        SubscriptionTrialEnded: Final = "subscription_trial_ended"
        SubscriptionWentActive: Final = "subscription_went_active"
        SubscriptionWentPastDue: Final = "subscription_went_past_due"
        TransactionDisbursed: Final = "transaction_disbursed"
        TransactionReviewed: Final = "transaction_reviewed"
        TransactionSettled: Final = "transaction_settled"
        TransactionSettlementDeclined: Final = "transaction_settlement_declined"

    @staticmethod
    def parse(signature, payload): ...
    @staticmethod
    def verify(challenge): ...
    source_merchant_id: Incomplete
    subscription: Subscription
    merchant_account: MerchantAccount
    transaction: Transaction
    transaction_review: TransactionReview
    connected_merchant_status_transitioned: ConnectedMerchantStatusTransitioned
    connected_merchant_paypal_status_changed: ConnectedMerchantPayPalStatusChanged
    partner_merchant: PartnerMerchant
    oauth_access_revocation: OAuthAccessRevocation
    disbursement: Disbursement
    dispute: Dispute
    account_updater_daily_report: AccountUpdaterDailyReport
    granted_payment_instrument_update: GrantedPaymentInstrumentUpdate
    revoked_payment_method_metadata: RevokedPaymentMethodMetadata
    local_payment_completed: LocalPaymentCompleted
    local_payment_expired: LocalPaymentExpired
    local_payment_funded: LocalPaymentFunded
    local_payment_reversed: LocalPaymentReversed
    payment_method_customer_data_updated_metadata: PaymentMethodCustomerDataUpdatedMetadata
    errors: ValidationErrorCollection
    message: Incomplete
    def __init__(self, gateway, attributes) -> None: ...



from _typeshed import Incomplete

class ApplePayGateway:
    gateway: Incomplete
    config: Incomplete
    def __init__(self, gateway) -> None: ...
    def register_domain(self, domain): ...
    def unregister_domain(self, domain): ...
    def registered_domains(self): ...



from _typeshed import Incomplete

from influxdb_client.domain.threshold_base import ThresholdBase

class RangeThreshold(ThresholdBase):
    openapi_types: Incomplete
    attribute_map: Incomplete
    discriminator: Incomplete
    def __init__(
        self,
        type: str = "range",
        min: Incomplete | None = None,
        max: Incomplete | None = None,
        within: Incomplete | None = None,
        level: Incomplete | None = None,
        all_values: Incomplete | None = None,
    ) -> None: ...
    @property
    def type(self): ...
    @type.setter
    def type(self, type) -> None: ...
    @property
    def min(self): ...
    @min.setter
    def min(self, min) -> None: ...
    @property
    def max(self): ...
    @max.setter
    def max(self, max) -> None: ...
    @property
    def within(self): ...
    @within.setter
    def within(self, within) -> None: ...
    def to_dict(self): ...
    def to_str(self): ...
    def __eq__(self, other): ...
    def __ne__(self, other): ...



from _typeshed import Incomplete

from networkx.utils.backends import _dispatch

@_dispatch
def biadjacency_matrix(
    G,
    row_order,
    column_order: Incomplete | None = None,
    dtype: Incomplete | None = None,
    weight: str = "weight",
    format: str = "csr",
): ...
@_dispatch
def from_biadjacency_matrix(A, create_using: Incomplete | None = None, edge_attribute: str = "weight"): ...



from _typeshed import Incomplete

from influxdb_client.domain.expression import Expression

class ConditionalExpression(Expression):
    openapi_types: Incomplete
    attribute_map: Incomplete
    discriminator: Incomplete
    def __init__(
        self,
        type: Incomplete | None = None,
        test: Incomplete | None = None,
        alternate: Incomplete | None = None,
        consequent: Incomplete | None = None,
    ) -> None: ...
    @property
    def type(self): ...
    @type.setter
    def type(self, type) -> None: ...
    @property
    def test(self): ...
    @test.setter
    def test(self, test) -> None: ...
    @property
    def alternate(self): ...
    @alternate.setter
    def alternate(self, alternate) -> None: ...
    @property
    def consequent(self): ...
    @consequent.setter
    def consequent(self, consequent) -> None: ...
    def to_dict(self): ...
    def to_str(self): ...
    def __eq__(self, other): ...
    def __ne__(self, other): ...



import sys
import types
from _typeshed import Incomplete, StrPath, TraceFunction
from collections.abc import Callable, Iterable, Mapping, Sequence
from typing import Any, TypeVar
from typing_extensions import ParamSpec, TypeAlias

__all__ = ["Trace", "CoverageResults"]

_T = TypeVar("_T")
_P = ParamSpec("_P")
_FileModuleFunction: TypeAlias = tuple[str, str | None, str]

class CoverageResults:
    counts: dict[tuple[str, int], int]
    counter: dict[tuple[str, int], int]
    calledfuncs: dict[_FileModuleFunction, int]
    callers: dict[tuple[_FileModuleFunction, _FileModuleFunction], int]
    inifile: StrPath | None
    outfile: StrPath | None
    def __init__(
        self,
        counts: dict[tuple[str, int], int] | None = None,
        calledfuncs: dict[_FileModuleFunction, int] | None = None,
        infile: StrPath | None = None,
        callers: dict[tuple[_FileModuleFunction, _FileModuleFunction], int] | None = None,
        outfile: StrPath | None = None,
    ) -> None: ...  # undocumented
    def update(self, other: CoverageResults) -> None: ...
    def write_results(self, show_missing: bool = True, summary: bool = False, coverdir: StrPath | None = None) -> None: ...
    def write_results_file(
        self, path: StrPath, lines: Sequence[str], lnotab: Any, lines_hit: Mapping[int, int], encoding: str | None = None
    ) -> tuple[int, int]: ...
    def is_ignored_filename(self, filename: str) -> bool: ...  # undocumented

class _Ignore:
    def __init__(self, modules: Iterable[str] | None = None, dirs: Iterable[StrPath] | None = None) -> None: ...
    def names(self, filename: str, modulename: str) -> int: ...

class Trace:
    inifile: StrPath | None
    outfile: StrPath | None
    ignore: _Ignore
    counts: dict[str, int]
    pathtobasename: dict[Incomplete, Incomplete]
    donothing: int
    trace: int
    start_time: int | None
    globaltrace: TraceFunction
    localtrace: TraceFunction
    def __init__(
        self,
        count: int = 1,
        trace: int = 1,
        countfuncs: int = 0,
        countcallers: int = 0,
        ignoremods: Sequence[str] = (),
        ignoredirs: Sequence[str] = (),
        infile: StrPath | None = None,
        outfile: StrPath | None = None,
        timing: bool = False,
    ) -> None: ...
    def run(self, cmd: str | types.CodeType) -> None: ...
    def runctx(
        self, cmd: str | types.CodeType, globals: Mapping[str, Any] | None = None, locals: Mapping[str, Any] | None = None
    ) -> None: ...
    if sys.version_info >= (3, 9):
        def runfunc(self, func: Callable[_P, _T], /, *args: _P.args, **kw: _P.kwargs) -> _T: ...
    else:
        def runfunc(self, func: Callable[_P, _T], *args: _P.args, **kw: _P.kwargs) -> _T: ...

    def file_module_function_of(self, frame: types.FrameType) -> _FileModuleFunction: ...
    def globaltrace_trackcallers(self, frame: types.FrameType, why: str, arg: Any) -> None: ...
    def globaltrace_countfuncs(self, frame: types.FrameType, why: str, arg: Any) -> None: ...
    def globaltrace_lt(self, frame: types.FrameType, why: str, arg: Any) -> None: ...
    def localtrace_trace_and_count(self, frame: types.FrameType, why: str, arg: Any) -> TraceFunction: ...
    def localtrace_trace(self, frame: types.FrameType, why: str, arg: Any) -> TraceFunction: ...
    def localtrace_count(self, frame: types.FrameType, why: str, arg: Any) -> TraceFunction: ...
    def results(self) -> CoverageResults: ...



from _thread import LockType, allocate_lock as Lock
from typing import Generic, NewType, TypeVar

__all__ = ["Lock", "Queue", "EmptyTimeout"]

_T = TypeVar("_T")
_Cookie = NewType("_Cookie", LockType)

class EmptyTimeout(Exception): ...

class Queue(Generic[_T]):
    unfinished_tasks: int
    def __init__(self) -> None: ...
    def task_done(self) -> None: ...
    def qsize(self) -> int: ...
    def empty(self) -> bool: ...
    def full(self) -> bool: ...
    def put(self, item: _T) -> None: ...
    def get(self, cookie: _Cookie, timeout: int = -1) -> _T: ...
    def allocate_cookie(self) -> _Cookie: ...
    def kill(self) -> None: ...



from _typeshed import Incomplete
from collections.abc import Generator

from networkx.utils.backends import _dispatch

@_dispatch
def cycle_basis(G, root: Incomplete | None = None): ...
@_dispatch
def simple_cycles(G, length_bound: Incomplete | None = None) -> Generator[Incomplete, Incomplete, None]: ...

class _NeighborhoodCache(dict[Incomplete, Incomplete]):
    G: Incomplete
    def __init__(self, G) -> None: ...
    def __missing__(self, v): ...

@_dispatch
def chordless_cycles(G, length_bound: Incomplete | None = None) -> Generator[Incomplete, Incomplete, None]: ...
@_dispatch
def recursive_simple_cycles(G): ...
@_dispatch
def find_cycle(G, source: Incomplete | None = None, orientation: Incomplete | None = None): ...
@_dispatch
def minimum_cycle_basis(G, weight: Incomplete | None = None): ...
